<?php
/*	
*	---------------------------------------------------------------------
*	MNKY Custom meta boxes
*	--------------------------------------------------------------------- 
*/


add_action( 'admin_init', 'mnky_custom_meta_boxes' );

function mnky_custom_meta_boxes() {
	
	$mnky_meta_page = array(
		'id'          => 'mnky_page_options',
		'title'       => esc_html__( 'Page Options', 'vital' ),
		'desc'        => '',
		'pages'       => array( 'page'),
		'context'     => 'normal',
		'priority'    => 'high',
		'fields'      => array(
			array(
				'id'          => 'general_tab',
				'label'       => esc_html__( 'General', 'vital' ),
				'desc'        => '',
				'std'         => '',
				'type'        => 'tab',
			),
			array(
				'label'       => esc_html__( 'Custom theme accent color', 'vital' ),
				'id'          => 'mnky_custom_accent_color',
				'desc'        => esc_html__( 'Set different accent color for this page. Leave blank for default color.', 'vital' ),
				'std'         => '',
				'type'        => 'colorpicker_opacity',
			),
			array(
				'label'       => esc_html__( 'Custom theme secondary accent color', 'vital' ),
				'id'          => 'mnky_custom_secondary_accent_color',
				'desc'        => esc_html__( 'Set different secondary accent color for this page. Leave blank for default color.', 'vital' ),
				'std'         => '',
				'type'        => 'colorpicker_opacity',
			),
			array(
				'id'          => 'mnky_custom_layout_style',
				'label'       => esc_html__( 'Layout style', 'vital' ),
				'desc'        => sprintf (esc_html_x( '1. Default layout %1$s 2. Full width layout %1$s 3. Boxed layout', '%1$s stands for line break' ,'vital' ), '<br/>'),
				'std'         => '',
				'type'        => 'radio-image',
			),
			array(
				'id'          => 'mnky_custom_body_background',
				'label'       => esc_html__( 'Body background', 'vital' ),
				'desc'        => esc_html__( 'Choose body background for boxed layout.', 'vital' ),
				'std'         => '',
				'type'        => 'background',
				'condition'   => 'mnky_custom_layout_style:is(boxed)',
			),			 
			array(
				'id'          => 'mnky_custom_content_width',
				'label'       => esc_html__( 'Content width', 'vital' ),
				'desc'        => esc_html__( 'This setting will apply selected layout width to your website. Leave empty for default.', 'vital' ),
				'std'         => '',
				'type'        => 'text',
			),
			array(
				'id'          => 'header_tab',
				'label'       => esc_html__( 'Header', 'vital' ),
				'desc'        => '',
				'std'         => '',
				'type'        => 'tab',
			),
			array(
				'id'          => 'mnky_sticky_header',
				'label'       => esc_html__( 'Sticky header', 'vital' ),
				'desc'        => esc_html__( 'Do you want a header to stick to top while you scroll?', 'vital' ),
				'std'         => '',
				'type'        => 'radio',
				'condition'   => '',
				'operator'    => 'and',
				'choices'     => array( 
				  array(
					'value'       => '',
					'label'       => esc_html__( 'Default (set in Theme Options)', 'vital' ),
					'src'         => ''
				  ),				  
				  array(
					'value'       => 'sticky_header_smart',
					'label'       => esc_html__( 'Smart header (sticky only when scrolling up)', 'vital' ),
					'src'         => ''
				  ),
				  array(
					'value'       => 'sticky_header',
					'label'       => esc_html__( 'Always sticky header', 'vital' ),
					'src'         => ''
				  ),
				  array(
					'value'       => 'no_sticky',
					'label'       => esc_html__( 'Disable sticky header', 'vital' ),
					'src'         => ''
				  )
				)
			  ),
			array(
				'label'       => esc_html__( 'Top bar', 'vital' ),
				'id'          => 'mnky_top_bar',
				'type'        => 'on-off',
				'desc'        => esc_html__( 'Disable top bar on this page only. If top bar is not enabled in theme options, this setting has no effect.', 'vital' ),
				'std'         => 'on'
			),	
			array(
				'label'       => esc_html__( 'Overlay header', 'vital' ),
				'id'          => 'mnky_header_overlay',
				'type'        => 'on-off',
				'desc'        => esc_html__( 'Enable overlay header on this page. Overlay header is configured in Theme Options/Header options/Overlay Header.', 'vital' ),
				'std'         => 'off'
			),			
			array(
				'label'       => esc_html__( 'Page title', 'vital' ),
				'id'          => 'mnky_page_title',
				'type'        => 'on-off',
				'desc'        => esc_html__( 'Display or hide page title.', 'vital' ),
				'std'         => 'on'
			),
			array(
				'id'          => 'precontent_tab',
				'label'       => esc_html__( 'Pre-content', 'vital' ),
				'desc'        => '',
				'std'         => '',
				'type'        => 'tab',
			),			
			array(
				'label'       => esc_html__( 'Pre-content area', 'vital' ),
				'id'          => 'mnky_pre_content_activation',
				'type'        => 'on-off',
				'desc'        => esc_html__( 'Activates additional area before main content.', 'vital' ),
				'std'         => 'off'
			 ),
			array(
				'label'       => esc_html__( 'Height (optional)', 'vital' ),
				'id'          => 'mnky_pre_content_height',
				'type'        => 'text',
				'desc'        => sprintf (esc_html_x( 'Pre-content area height. Example: %s', '%s stands for example value. Do not delete it.' ,'vital' ), '<code>250px</code>'),
				'condition'   => 'mnky_pre_content_activation:is(on)',
				'class'       => 'child-options child-first'
			),
			array(
				'label'       => esc_html__( 'Responsive height (optional)', 'vital' ),
				'id'          => 'mnky_pre_content_responsive_height',
				'type'        => 'on-off',
				'desc'        => esc_html__( 'Enables auto height in responsive mode.', 'vital' ),
				'condition'   => 'mnky_pre_content_activation:is(on)',
				'std'         => 'off',
				'class'       => 'child-options'
			),
			array(
				'label'       => esc_html__( 'Max width (optional)', 'vital' ),
				'id'          => 'mnky_pre_content_width',
				'type'        => 'text',
				'desc'        => sprintf (esc_html_x( 'Pre-content area max width. Example: %s', '%s stands for example value. Do not delete it.' ,'vital' ), '<code>1200px</code>'),
				'condition'   => 'mnky_pre_content_activation:is(on)',
				'class'       => 'child-options'
			),
			array(
				'label'       => esc_html__( 'Paddings (optional)', 'vital' ),
				'id'          => 'mnky_pre_content_paddings',
				'type'        => 'text',
				'desc'        => sprintf (esc_html_x( 'Pre-content area paddings. Example: %s', '%s stands for example value. Do not delete it.' ,'vital' ), '<code>40px</code>'),
				'condition'   => 'mnky_pre_content_activation:is(on)',
				'class'       => 'child-options'
			),
			array(
				'id'          => 'mnky_pre_content_bg',
				'label'       => esc_html__( 'Background', 'vital' ),
				'desc'        => esc_html__( 'Set custom background color or image.', 'vital' ),
				'type'        => 'background',
				'rows'        => '',
				'condition'   => 'mnky_pre_content_activation:is(on)',
				'class'       => 'child-options'
			),
			array(
				'label'       => esc_html__( 'Custom HTML', 'vital' ),
				'id'          => 'mnky_pre_content_html',
				'type'        => 'textarea',
				'rows'        => '4',
				'desc'        => esc_html__( 'Insert any custom code you wish. Shortcodes are allowed.', 'vital' ),
				'condition'   => 'mnky_pre_content_activation:is(on)',
				'class'       => 'child-options child-last'
			),
			array(
				'id'          => 'section_scroll_tab',
				'label'       => esc_html__( 'Section scroll', 'vital' ),
				'desc'        => '',
				'std'         => '',
				'type'        => 'tab',
			),
			array(
				'label'       => esc_html__( 'Enable section scroll', 'vital' ),
				'id'          => 'mnky_section_scroll',
				'desc'        => esc_html( 'Advance full section on each scroll. <br/><br/><strong>Important Notes:</strong><br/> 1. Works best with overlay header.<br/>2. Choose page template with no vertical paddings.<br/>3. Elements preceding first section should be disabled (turn off page title and pre-content area).', 'vital' ),
				'type'        => 'on-off',
				'std'         => 'off',
			),			
			array(
				'label'       => esc_html__( 'Animation', 'vital' ),
				'id'          => 'mnky_section_animation',
				'desc'        => '',
				'type'        => 'on-off',
				'std'         => 'on',
				'condition'   => 'mnky_section_scroll:is(on)',
			),
			array(
				'label'       => esc_html__( 'Show Pagination?', 'vital' ),
				'id'          => 'mnky_section_pagination',
				'desc'        => '',
				'type'        => 'on-off',
				'std'         => 'off',
				'condition'   => 'mnky_section_scroll:is(on)',
			),
			array(
				'label'       => esc_html__( 'Section pagination color', 'vital' ),
				'id'          => 'mnky_section_pagination_color',
				'desc'        => '',
				'std'         => '#fff',
				'type'        => 'colorpicker_opacity',
				'condition'   => 'mnky_section_scroll:is(on),mnky_section_pagination:is(on)',
			),

		)
	);
	
	$mnky_meta_post = array(
		'id'          => 'mnky_post_options',
		'title'       => esc_html__( 'Post Options', 'vital' ),
		'desc'        => '',
		'pages'       => array( 'post' ),
		'context'     => 'normal',
		'priority'    => 'core',
		'fields'      => array(
			array(
				'id'          => 'general_tab',
				'label'       => esc_html__( 'General', 'vital' ),
				'desc'        => '',
				'std'         => '',
				'type'        => 'tab',
			),
			array(
				'label'       => esc_html__( 'Custom theme accent color', 'vital' ),
				'id'          => 'mnky_custom_accent_color',
				'desc'        => esc_html__( 'Set different accent color for this page. Leave blank for default color.', 'vital' ),
				'std'         => '',
				'type'        => 'colorpicker_opacity',
			),
			array(
				'label'       => esc_html__( 'Custom theme secondary accent color', 'vital' ),
				'id'          => 'mnky_custom_secondary_accent_color',
				'desc'        => esc_html__( 'Set different secondary accent color for this page. Leave blank for default color.', 'vital' ),
				'std'         => '',
				'type'        => 'colorpicker_opacity',
			),
			array(
				'id'          => 'mnky_custom_layout_style',
				'label'       => esc_html__( 'Layout style', 'vital' ),
				'desc'        => sprintf (esc_html_x( '1. Default layout %1$s Selected in Appearance / Theme Options / General Options %1$s%1$s 2. Full width layout %1$s3. Boxed layout', '%1$s stands for line break' ,'vital' ), '<br/>'),
				'std'         => '',
				'type'        => 'radio-image',
				'section'     => 'general',
			),
			array(
				'id'          => 'mnky_custom_body_background',
				'label'       => esc_html__( 'Body background', 'vital' ),
				'desc'        => esc_html__( 'Choose body background for boxed layout.', 'vital' ), 
				'std'         => '',
				'type'        => 'background',
				'section'     => 'general',
				'condition'   => 'mnky_custom_layout_style:is(boxed)',
			),			 
			array(
				'id'          => 'mnky_custom_content_width',
				'label'       => esc_html__( 'Content width', 'vital' ),
				'desc'        => esc_html__( 'This setting will apply selected layout width to your website. Leave empty for default.', 'vital' ), 
				'std'         => '',
				'type'        => 'text',
				'section'     => 'general',
			),
			array(
				'label'       => esc_html__( 'Top bar', 'vital' ),
				'id'          => 'mnky_top_bar',
				'type'        => 'on-off',
				'desc'        => esc_html__( 'Disable top bar on this page only. If top bar is not enabled in theme options, this setting has no effect.', 'vital' ),
				'std'         => 'on'
			),	
			array(
				'id'          => 'post_options_tab',
				'label'       => esc_html__( 'Post settings', 'vital' ),
				'desc'        => '',
				'std'         => '',
				'type'        => 'tab',
			),
			array(
				'id'          => 'mnky_post_lead_content',
				'label'       => esc_html__( 'Lead content', 'vital' ),
				'desc'        => esc_html__( 'Optional content displayed below the title. Shortcode enabled. It will not be included into post excerpt.', 'vital' ),
				'std'         => '',
				'type'        => 'textarea',
				'rows'        => '4'
			),		
			array(
				'label'       => esc_html__( 'Post title area', 'vital' ),
				'id'          => 'mnky_single_post_header',
				'type'        => 'on-off',
				'desc'        => esc_html__( 'Enable default title area for this post.', 'vital' ),
				'std'         => 'on'
			), 
			array(
				'label'       => esc_html__( 'Featured image after title', 'vital' ),
				'id'          => 'mnky_content_featured_img',
				'type'        => 'on-off',
				'desc'        => esc_html__( 'Do you want to display featured image after title in content?', 'vital' ),
				'std'         => 'on'
			),
			array(
				'id'          => 'mnky_custom_content_style',
				'label'       => esc_html__( 'Content style', 'vital' ),
				'desc'        => '',
				'std'         => '',
				'type'        => 'select',
				'desc'        => sprintf (esc_html_x( '1. Standard one column %1$s 2. Divided with featured image on the left %1$s 3. Divided with featured image on the right', '%1$s stands for line break' ,'vital' ), '<br/>'),
				'choices'     => array( 
				  array(
					'value'       => '1',
					'label'       => esc_html__( 'Standard one column', 'vital' ),
					'src'         => ''
				  ),
				  array(
					'value'       => '2',
					'label'       => esc_html__( 'Divided with featured image on the left', 'vital' ),
					'src'         => ''
				  ),
				  array(
					'value'       => '3',
					'label'       => esc_html__( 'Divided with featured image on the right', 'vital' ),
					'src'         => ''
				  )  				  
				)
			),
						array(
				'label'       => esc_html__( 'Set different width for paragraphs', 'vital' ),
				'id'          => 'mnky_post_width',
				'type'        => 'text',
				'std'         => '',
				'desc'        => esc_html__( 'Specify maximum width for text paragraphs without affecting other content , e.g., images.', 'vital' ),
			),
			array(
				'label'       => esc_html__( 'Post labels', 'vital' ),
				'id'          => 'mnky_post_labels',
				'type'        => 'list_item',
				'std'         => '',
				'desc'        => esc_html__( 'Add some labels to the post, e.g., "Sponsored Content"', 'vital' ),
				'settings'    => array( 
				array(
					'id'          => 'mnky_post_label_text',
					'label'       => esc_html__( 'Label text', 'vital' ),
					'desc'        => '',
					'std'         => '',
					'type'        => 'text',
					'operator'    => 'and'
				  ),
				array(
					'id'          => 'mnky_post_label_color',
					'label'       => esc_html__( 'Choose label color', 'vital' ),
					'desc'        => '',
					'std'         => '',
					'type'        => 'colorpicker_opacity',
					'operator'    => 'and'
				  )
				)

			),
			array(
				'id'          => 'precontent_tab',
				'label'       => esc_html__( 'Pre-content', 'vital' ),
				'desc'        => '',
				'std'         => '',
				'type'        => 'tab',
			),
			array(
				'label'       => esc_html__( 'Pre-content area', 'vital' ),
				'id'          => 'mnky_pre_content_activation',
				'type'        => 'on-off',
				'desc'        => esc_html__( 'Activates additional area before main content.', 'vital' ),
				'std'         => 'off'
			),
			array(
				'label'       => esc_html__( 'Height (optional)', 'vital' ),
				'id'          => 'mnky_pre_content_height',
				'type'        => 'text',
				'desc'        => sprintf (esc_html_x( 'Pre-content area height. Example: %s', '%s stands for example value. Do not delete it.' ,'vital' ), '<code>250px</code>'),
				'condition'   => 'mnky_pre_content_activation:is(on)',
				'class'       => 'child-options child-first'
			),
			array(
				'label'       => esc_html__( 'Responsive height (optional)', 'vital' ),
				'id'          => 'mnky_pre_content_responsive_height',
				'type'        => 'on-off',
				'desc'        => esc_html__( 'Enables auto height in responsive mode.', 'vital' ),
				'condition'   => 'mnky_pre_content_activation:is(on)',
				'std'         => 'off',
				'class'       => 'child-options'
			),
			array(
				'label'       => esc_html__( 'Max width (optional)', 'vital' ),
				'id'          => 'mnky_pre_content_width',
				'type'        => 'text',
				'desc'        => sprintf (esc_html_x( 'Pre-content area max width. Example: %s', '%s stands for example value. Do not delete it.' ,'vital' ), '<code>1200px</code>'),
				'condition'   => 'mnky_pre_content_activation:is(on)',
				'class'       => 'child-options'
			),
			array(
				'label'       => esc_html__( 'Paddings (optional)', 'vital' ),
				'id'          => 'mnky_pre_content_paddings',
				'type'        => 'text',
				'desc'        => sprintf (esc_html_x( 'Pre-content area paddings. Example: %s', '%s stands for example value. Do not delete it.' ,'vital' ), '<code>40px</code>'),
				'condition'   => 'mnky_pre_content_activation:is(on)',
				'class'       => 'child-options'
			),
			array(
				'id'          => 'mnky_pre_content_bg',
				'label'       => esc_html__( 'Background', 'vital' ),
				'desc'        => esc_html__( 'Set custom background color or image.', 'vital' ),
				'type'        => 'background',
				'rows'        => '',
				'condition'   => 'mnky_pre_content_activation:is(on)',
				'class'       => 'child-options'
			),
			array(
				'label'       => esc_html__( 'Custom HTML', 'vital' ),
				'id'          => 'mnky_pre_content_html',
				'type'        => 'textarea',
				'rows'        => '4',
				'desc'        => esc_html__( 'Insert any custom code you wish. Shortcodes are allowed.', 'vital' ),
				'condition'   => 'mnky_pre_content_activation:is(on)',
				'class'       => 'child-options child-last'
			)
		)
	
	);
	
	$mnky_meta_featured_image_caption = array(
		'id'          => 'mnky_featured_image_caption',
		'title'       => esc_html__( 'Featured image caption', 'vital' ),
		'desc'        => '',
		'pages'       => array( 'post' ),
		'context'     => 'side',
		'priority'    => 'core',
		'fields'      => array(			
			array(
				'label'       => '',
				'id'          => 'mnky_featured_image_caption_text',
				'type'        => 'text',
				'std'         => '',
				'desc'        => esc_html__( 'Optional caption text for the featured image. Simple HTML allowed. *If featured image in content is disabled, will be displayed below header image, if present.', 'vital' )
			)
		)
	);
	
	$mnky_meta_custom_post_link= array(
		'id'          => 'mnky_custom_post_link',
		'title'       => esc_html__( 'Custom url for link post type', 'vital' ),
		'desc'        => '',
		'pages'       => array( 'post' ),
		'context'     => 'side',
		'priority'    => 'core',
		'fields'      => array(			
			array(
				'label'       => '',
				'id'          => 'mnky_custom_post_link_url',
				'type'        => 'text',
				'std'         => '',
				'desc'        => esc_html__( 'Optional custom url for the link post type. Applied to title and featured image in blog view. Supports external links.', 'vital' )
			)
		)
	);
	
	$mnky_meta_post_reviews = array(
		'id'          => 'mnky_post_reviews',
		'title'       => esc_html__( 'Product Review', 'vital' ),
		'desc'        => '',
		'pages'       => array( 'post' ),
		'context'     => 'normal',
		'priority'    => 'core',
		'fields'      => array(		
			array(
			'label'       => esc_html__( 'Enable Reviews', 'vital' ),
			'id'          => 'mnky_enable_review',
			'type'        => 'on-off',
			'desc'        => esc_html__( 'Add review functionality to this post.', 'vital' ),
			'std'         => 'off'	
			),
			array(
				'label'       => esc_html__( 'Review position', 'vital'),
				'id'          => 'mnky_review_position',
				'type'        => 'select',
				'choices'     => array( 
					array(
						'value'       => 'top',
						'label'       => esc_html__( 'Top of the post', 'vital' ),
						'src'         => ''
					),
					array(
						'value'       => 'bottom',
						'label'       => esc_html__( 'Bottom of the post', 'vital' ),
						'src'         => ''
					)
				),	
				'std'         => '',
				'condition'   => 'mnky_enable_review:is(on)',
				'desc'        => esc_html__( 'Choose where review will appear', 'vital' )
			),
			array(
				'label'       => esc_html__( 'Review title', 'vital'),
				'id'          => 'mnky_review_title',
				'type'        => 'text',
				'std'         => '',
				'condition'   => 'mnky_enable_review:is(on)',
				'desc'        => esc_html__( 'Name this review', 'vital' )
			),
			array(
				'label'       => esc_html__( 'Overall rating', 'vital'),
				'id'          => 'mnky_review_overall_rating',
				'type'        => 'numeric-slider',
				'std'         => '5',
				'min_max_step'=> '0,10,0.1',
				'condition'   => 'mnky_enable_review:is(on)',
				'desc'        => esc_html__( 'Give overall rating from 0 to 10 to this product.', 'vital' )
			),
			array(
				'label'       => esc_html__( 'Use review breakdown', 'vital' ),
				'id'          => 'mnky_review_breakdown',
				'type'        => 'on-off',
				'condition'   => 'mnky_enable_review:is(on)',
				'desc'        => esc_html__( 'If this option is active, overall review rating will be calculated from the ratings in the list.', 'vital' ),
				'std'         => 'off'
			), 	
			array(
				'label'       => esc_html__( 'Review ratings breakdown', 'vital' ),
				'id'          => 'mnky_review_ratings',
				'type'        => 'list_item',
				'std'         => '',
				'desc'        => esc_html__( 'Rate product from various aspects, e.g., "Design, Features, Performance"', 'vital' ),
				'condition'   => 'mnky_enable_review:is(on),mnky_review_breakdown:is(on)',
				'class'       => 'child-options child-first child-last',	
				'settings'    => array( 
				array(
					'id'          => 'mnky_review_aspect_name',
					'label'       => esc_html__( 'Name', 'vital' ),
					'std'         => '',
					'type'        => 'text',
					'desc'        => esc_html__( 'Name this review aspect,  e.g., "Design"', 'vital' ),
					'operator'    => 'and'
				  ),
				array(
					'id'          => 'mnky_review_aspect_rating',
					'label'       => esc_html__( 'Rating', 'vital' ),
					'desc'        => '',
					'type'        => 'numeric-slider',
					'std'         => '5',
					'min_max_step'=> '0,10,0.1',
					'operator'    => 'and'
				  )
				)
			),
			array(
				'label'       => esc_html__( 'Good things', 'vital' ),
				'id'          => 'mnky_review_good_title',
				'type'        => 'text',
				'std'         => '',
				'condition'   => 'mnky_enable_review:is(on)',
				'desc'        => esc_html__( 'Add title for describing good things in this product, e.g, "The Good"', 'vital' )
			),
			array(
				'label'       => '',
				'id'          => 'mnky_review_good',
				'type'        => 'textarea',
				'std'         => '',
				'condition'   => 'mnky_enable_review:is(on)',
				'desc'        => esc_html__( 'Describe what was good in this product', 'vital' )
			),
			array(
				'label'       => esc_html__( 'Bad things', 'vital' ),
				'id'          => 'mnky_review_bad_title',
				'type'        => 'text',
				'std'         => '',
				'condition'   => 'mnky_enable_review:is(on)',
				'desc'        => esc_html__( 'Add title for describing bad things in this product, e.g, "The Bad"', 'vital' )
			),
			array(
				'label'       => '',
				'id'          => 'mnky_review_bad',
				'type'        => 'textarea',
				'std'         => '',
				'condition'   => 'mnky_enable_review:is(on)',
				'desc'        => esc_html__( 'Describe what was bad in this product', 'vital' )
			),
			array(
				'label'       => esc_html__( 'Bottom line', 'vital' ),
				'id'          => 'mnky_review_bottomline_title',
				'type'        => 'text',
				'std'         => '',
				'condition'   => 'mnky_enable_review:is(on)',
				'desc'        => esc_html__( 'Add title for describing the bottom line of this product, e.g, "The Bottom Line"', 'vital' )
			),
			array(
				'label'       => '',
				'id'          => 'mnky_review_bottomline',
				'type'        => 'textarea',
				'std'         => '',
				'condition'   => 'mnky_enable_review:is(on)',
				'desc'        => esc_html__( 'So what is the bottom line for this product?', 'vital' )
			),
			array(
				'label'       => esc_html__( 'Custom content', 'vital' ),
				'id'          => 'mnky_review_custom_field',
				'type'        => 'textarea',
				'std'         => '',
				'condition'   => 'mnky_enable_review:is(on)',
				'desc'        => esc_html__( 'Add any custom content here, shortcodes are allowed', 'vital' )
			)
		)
	);
	
	$mnky_meta_ads = array(
		'id'          => 'mnky_ads_options',
		'title'       => esc_html__( 'Ad Options', 'vital' ),
		'desc'        => '',
		'pages'       => array( 'ads' ),
		'context'     => 'normal',
		'priority'    => 'high',
		'fields'      => array(			
			array(
				'label'       => esc_html__( 'URL', 'vital' ),
				'id'          => 'mnky_ad_url',
				'type'        => 'text',
				'desc'        => sprintf (esc_html_x( 'Include %1$s %2$s or %3$s', '%1$s, %2$s, %3$s stand for protocol types.' ,'vital' ), '<code>http://</code>', '<code>https://</code>', '<code>//</code>')
			),
			array(
				'id'          => 'mnky_ad_url_target',
				'label'       => esc_html__( 'Target', 'vital' ),
				'desc'        => '',
				'std'         => '',
				'type'        => 'select',
				'desc'        => esc_html__( 'The target attribute specifies how to open the link.', 'vital' ),
				'choices'     => array( 
					array(
						'value'       => '_blank',
						'label'       => esc_html__( '_blank (opens in new window or tab)', 'vital' ),
						'src'         => ''
					),
					array(
						'value'       => '_self',
						'label'       => esc_html__( '_self (opens in the same frame as it was clicked)', 'vital' ),
						'src'         => ''
					)
				),	
				'operator'    => 'and',
				'condition'   => 'mnky_ad_url:not()'
			),			
			array(
				'id'          => 'mnky_ad_url_rel',
				'label'       => esc_html__( 'Use rel="nofollow"', 'vital' ),
				'desc'        => '',
				'std'         => '',
				'type'        => 'select',
				'desc'        => sprintf( wp_kses_post( _x( 'Specifies the relationship between the current document and the linked document. %1$s <a href="%2$s">Should I use it?</a>', '%1$s stands for line break, %2$s stands for linked page.','vital' ) ), '<br/>', esc_url( 'https://support.google.com/webmasters/answer/96569?hl=en' ) ),
				'choices'     => array( 
					array(
						'value'       => '',
						'label'       => esc_html__( 'No', 'vital' ),
						'src'         => ''
					),
					array(
						'value'       => 'rel=nofollow',
						'label'       => esc_html__( 'Yes', 'vital' ),
						'src'         => ''
					)
				),	
				'operator'    => 'and',
				'condition'   => 'mnky_ad_url:not()'
			),
			array(
				'label'       => esc_html__( 'Alternative text', 'vital' ),
				'id'          => 'mnky_ad_alt_text',
				'type'        => 'text',
				'desc'        => esc_html__( 'Add text for alt attribute.', 'vital' )
			),	
			array(
				'label'       => esc_html__( 'Advertisement block width', 'vital' ),
				'id'          => 'mnky_ad_width',
				'type'        => 'text',
				'desc'        => sprintf (esc_html_x( 'Specify maximum ad block width, e.g. %s', '%s stands for example value, do not delete it.' ,'vital' ), '<code>140px</code>')
			),			
			array(
				'label'       => esc_html__( 'Advertisement block height (optional)', 'vital' ),
				'id'          => 'mnky_ad_height',
				'type'        => 'text',
				'desc'        => sprintf (esc_html_x( 'Specify maximum ad block height, e.g. %1$s %2$s Will cut off ad block, if value smaller than actual ad size used.', '%1$s stands for example value, %2$s stands for line break.' ,'vital' ), '<code>440px</code>', '<br/>')
			),
			array(
				'label'       => esc_html__( 'Advertisement block position (optional)', 'vital' ),
				'id'          => 'mnky_ad_position',
				'type'        => 'text',
				'desc'        => sprintf (esc_html_x( 'Specify ad block position using css margin: property. %1$s For example %2$s will center the ad inside.', '%1$s stands for line break, %2$s stands for example value.' ,'vital' ), '<br/>', '<code>0 auto</code>')
			),
			array(
				'label'       => esc_html__( 'Advertisement block float (optional)', 'vital' ),
				'id'          => 'mnky_ad_float',
				'type'        => 'text',
				'desc'        => sprintf (esc_html_x( 'Specify ad block float using css float: property. %1$s For example %2$s will float ad to the left side.', '%1$s stands for line break, %2$s stands for example value.' ,'vital' ), '<br/>', '<code>left</code>')
			),
			array(
				'id'          => 'mnky_ad_image',
				'label'       => esc_html__( 'Advertisement Image', 'vital' ),
				'desc'        => esc_html__( 'Choose advertisement image.', 'vital' ),
				'std'         => '',
				'type'        => 'upload'
			),
			array(
				'label'       => esc_html__( 'Advertisement image width', 'vital' ),
				'id'          => 'mnky_ad_image_width',
				'type'        => 'text',
				'desc'        => sprintf (esc_html_x( 'Specify width of ad image for the "width" html attribute, e.g. %s', '%s stands for example value, do not delete it.' ,'vital' ), '<code>140</code>')
			),			
			array(
				'label'       => esc_html__( 'Advertisement image height', 'vital' ),
				'id'          => 'mnky_ad_image_height',
				'type'        => 'text',
				'desc'        => sprintf (esc_html_x( 'Specify height of ad image for the "height" html attribute, e.g. %1$s %2$s It will not affect actual image display height.', '%1$s stands for example value, %2$s stands for line break.', 'vital' ), '<code>400</code>', '<br/>')
			),
			array(
				'label'       => esc_html__( 'Responsive advertisement image', 'vital' ),
				'id'          => 'mnky_responsive_ad',
				'type'        => 'on-off',
				'desc'        => esc_html__('Use different image for smaller screens', 'vital' ),
				'std'         => 'off'
			), 
			array(
				'label'       => esc_html__( 'Advertisement Image', 'vital' ),
				'id'          => 'mnky_responsive_ad_image',
				'std'         => '',
				'type'        => 'upload',
				'desc'        => esc_html__( 'Choose advertisement image for screens below 979px (Tablet portrait) and below 1024px (Tablet landscape), if placed in header widget area.', 'vital' ),
				'condition'   => 'mnky_responsive_ad:is(on)',
				'class'       => 'child-options child-first'				
			),
			array(
				'label'       => esc_html__( 'Responsive advertisement image width', 'vital' ),
				'id'          => 'mnky_responsive_ad_image_width',
				'type'        => 'text',
				'desc'        => sprintf (esc_html_x( 'Specify width of ad image for the "width" html attribute, e.g. %s', '%s stands for example value. Do not delete it.', 'vital' ), '<code>140</code>'),
				'condition'   => 'mnky_responsive_ad:is(on)',
				'class'       => 'child-options'				
			),			
			array(
				'label'       => esc_html__( 'Responsive advertisement image height', 'vital' ),
				'id'          => 'mnky_responsive_ad_image_height',
				'type'        => 'text',
				'desc'        => sprintf (esc_html_x( 'Specify height of ad image for the "height" html attribute, e.g. %1$s %2$s It will not affect actual image display height.', '%1$s stands for example value, %2$s stands for line break.', 'vital' ), '<code>400</code>', '<br/>'),
				'condition'   => 'mnky_responsive_ad:is(on)',
				'class'       => 'child-options child-last'				
			),
			array(
				'label'       => esc_html__( 'Hide ad on mobiles', 'vital' ),
				'id'          => 'mnky_hide_responsive_ad',
				'type'        => 'on-off',
				'desc'        =>  esc_html__( 'Hide advertisement on screens smaller than 767px (Mobile phones).', 'vital' ),
				'std'         => 'off'
			), 
			array(
				'label'       => esc_html__( 'Label', 'vital' ),
				'id'          => 'mnky_ad_note',
				'type'        => 'text',
				'desc'        => esc_html__( 'Optional label under advertisement, e.g. "Sponsored" or "Advertisement".', 'vital' )
			),	
			array(
				'label'       => '',
				'id'          => 'mnky_ads_textblock',
				'type'        => 'textblock',
				'desc'        => '<div class="section-title">'. esc_html__( 'If you use Custom HTML, you can leave fields above empty.', 'vital' ) .'</div>'
			),			
			array(
				'label'       => esc_html__( 'Custom HTML', 'vital' ),
				'id'          => 'mnky_ad_html',
				'type'        => 'textarea',
				'rows'        => '14',
				'desc'        => esc_html__( 'Insert any custom code.', 'vital' )
			)
		)
	);
	
	$mnky_meta_product = array(
		'id'          => 'mnky_product_options',
		'title'       => esc_html__( 'Page Options', 'vital' ),
		'desc'        => '',
		'pages'       => 'product',
		'context'     => 'normal',
		'priority'    => 'high',
		'fields'      => array(
			array(
				'label'       => esc_html__( 'Custom theme accent color', 'vital' ),
				'id'          => 'mnky_custom_accent_color',
				'desc'        => esc_html__( 'Set different accent color for this page. Leave blank for default color', 'vital' ),
				'std'         => '',
				'type'        => 'colorpicker_opacity',
			 ),
			 array(
				'label'       => esc_html__( 'Custom theme secondary accent color', 'vital' ),
				'id'          => 'mnky_custom_secondary_accent_color',
				'desc'        => esc_html__( 'Set different secondary accent color for this page. Leave blank for default color.', 'vital' ),
				'std'         => '',
				'type'        => 'colorpicker_opacity',
			),
			array(
				'label'       => esc_html__( 'Pre-content area', 'vital' ),
				'id'          => 'mnky_pre_content_activation',
				'type'        => 'on-off',
				'desc'        => esc_html__( 'Activates additional area before main content', 'vital' ),
				'std'         => 'off'
			 ),
			array(
				'label'       => esc_html__( 'Height (optional)', 'vital' ),
				'id'          => 'mnky_pre_content_height',
				'type'        => 'text',
				'desc'        => sprintf (esc_html_x( 'Pre-content area height. Example: %s', '%s stands for example value. Do not delete it.' ,'vital' ), '<code>250px</code>'),
				'condition'   => 'mnky_pre_content_activation:is(on)',
				'class'       => 'child-options child-first'
			),
			array(
				'label'       => esc_html__( 'Responsive height (optional)', 'vital' ),
				'id'          => 'mnky_pre_content_responsive_height',
				'type'        => 'on-off',
				'desc'        => esc_html__( 'Enables auto height in responsive mode.', 'vital' ),
				'condition'   => 'mnky_pre_content_activation:is(on)',
				'std'         => 'off',
				'class'       => 'child-options'
			),
			array(
				'label'       => esc_html__( 'Max width (optional)', 'vital' ),
				'id'          => 'mnky_pre_content_width',
				'type'        => 'text',
				'desc'        => sprintf (esc_html_x( 'Pre-content area max width. Example: %s', '%s stands for example value. Do not delete it.' ,'vital' ), '<code>1200px</code>'),
				'condition'   => 'mnky_pre_content_activation:is(on)',
				'class'       => 'child-options'
			),
			array(
				'label'       => esc_html__( 'Paddings (optional)', 'vital' ),
				'id'          => 'mnky_pre_content_paddings',
				'type'        => 'text',
				'desc'        => sprintf (esc_html_x( 'Pre-content area paddings. Example: %s', '%s stands for example value. Do not delete it.' ,'vital' ), '<code>40px</code>'),
				'condition'   => 'mnky_pre_content_activation:is(on)',
				'class'       => 'child-options'
			),
			array(
				'id'          => 'mnky_pre_content_bg',
				'label'       => esc_html__( 'Background', 'vital' ),
				'desc'        => 'Set custom background color or image',
				'type'        => 'background',
				'rows'        => '',
				'condition'   => 'mnky_pre_content_activation:is(on)',
				'class'       => 'child-options'
			),
			array(
				'label'       => esc_html__( 'Custom HTML', 'vital' ),
				'id'          => 'mnky_pre_content_html',
				'type'        => 'textarea',
				'rows'        => '4',
				'desc'        => esc_html__( 'Insert any custom code you wish. Shortcodes are allowed', 'vital' ),
				'condition'   => 'mnky_pre_content_activation:is(on)',
				'class'       => 'child-options child-last'
			)
		)
	);	
	
	
  
	if ( function_exists( 'ot_register_meta_box' ) ) {
		ot_register_meta_box( $mnky_meta_page );
		ot_register_meta_box( $mnky_meta_post );
		ot_register_meta_box( $mnky_meta_product );
		ot_register_meta_box( $mnky_meta_ads );
		ot_register_meta_box( $mnky_meta_featured_image_caption );
		ot_register_meta_box( $mnky_meta_custom_post_link );
		ot_register_meta_box( $mnky_meta_post_reviews );
	}
}