<?php
/**
 * Initialize the custom theme options.
 */
add_action( 'init', 'custom_theme_options' );

/**
 * Build the custom settings & update OptionTree.
 */
function custom_theme_options() {
  
  /* OptionTree is not loaded yet, or this is not an admin request */
  if ( ! function_exists( 'ot_settings_id' ) || ! is_admin() )
    return false;
    
  /**
   * Get a copy of the saved settings array. 
   */
  $saved_settings = get_option( ot_settings_id(), array() );
  
  /**
   * Custom settings array that will eventually be 
   * passes to the OptionTree Settings API Class.
   */
  $custom_settings = array( 
    'contextual_help' => array( 
      'sidebar'       => ''
    ),
    'sections'        => array( 
      array(
        'id'          => 'general',
        'title'       => esc_html__( 'General Options', 'vital' )
      ),
      array(
        'id'          => 'header_options',
        'title'       => esc_html__( 'Header Options', 'vital' )
      ),
	  array(
        'id'          => 'navigation_options',
        'title'       => esc_html__( 'Menu Options', 'vital' )
      ),
      array(
        'id'          => 'color_options',
        'title'       => esc_html__( 'Content Colors', 'vital' )
      ),
      array(
        'id'          => 'typography',
        'title'       => esc_html__( 'Typography', 'vital' )
      ),
      array(
        'id'          => 'footer_options',
        'title'       => esc_html__( 'Footer', 'vital' )
      ),
      array(
        'id'          => 'articles_section',
        'title'       => esc_html__( 'Single Post', 'vital' )
      ),
      array(
        'id'          => 'blog_section',
        'title'       => esc_html__( 'Blog  Options', 'vital' )
      ),
      array(
        'id'          => 'category_style_tab',
        'title'       => esc_html__( 'Categories', 'vital' )
      ),
      array(
        'id'          => 'woocommerce',
        'title'       => esc_html__( 'WooCommerce', 'vital' )
      ),
      array(
        'id'          => 'custom_css',
        'title'       => esc_html__( 'Custom CSS', 'vital' )
      )
    ),
    'settings'        => array( 
      array(
        'id'          => 'accent_color',
        'label'       => esc_html__( 'Theme accent color', 'vital' ),
        'desc'        => esc_html__( 'This will be general color scheme for your website. Click input field for color picker.', 'vital' ),
        'std'         => '#3498db',
        'type'        => 'colorpicker_opacity',
        'section'     => 'general',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
	  array(
        'id'          => 'secondary_accent_color',
        'label'       => esc_html__( 'Theme secondary accent color', 'vital' ),
        'desc'        => esc_html__( 'This will be secondary color for your website. Click input field for color picker.', 'vital' ),
        'std'         => '#f39c12',
        'type'        => 'colorpicker_opacity',
        'section'     => 'general',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'layout_style',
        'label'       => esc_html__( 'Layout style', 'vital' ),
		'desc'        => sprintf (esc_html_x( '1. Full width layout %1$s 2. Boxed layout', '%1$s stands for line break' ,'vital' ), '<br/>'),
        'std'         => 'full-width',
        'type'        => 'radio-image',
        'section'     => 'general',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'body_background',
        'label'       => esc_html__( 'Body background', 'vital' ),
        'desc'        => esc_html__( 'Choose body background for boxed layout.', 'vital' ),
        'std'         => '',
        'type'        => 'background',
        'section'     => 'general',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => 'layout_style:is(boxed)',
        'operator'    => 'and'
      ),
	  array(
        'id'          => 'content_width',
        'label'       => esc_html__( 'Content width', 'vital' ),
        'desc'        => esc_html__( 'This setting will apply selected layout width in pixels to your website.', 'vital' ),
        'std'         => '1200',
        'type'        => 'text',
        'section'     => 'general',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'sticky_sidebar',
        'label'       => esc_html__( 'Sticky sidebar', 'vital' ),
        'desc'        => esc_html__( 'If enabled, sidebar will always be visible while you scroll.', 'vital' ),
        'std'         => 'on',
        'type'        => 'on-off',
        'section'     => 'general',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'scroll_to_top_button',
        'label'       => esc_html__( 'Scroll to top button', 'vital' ),
        'desc'        => esc_html__( 'Enable or disable "To Top" button when you scroll down.', 'vital' ),
        'std'         => 'on',
        'type'        => 'on-off',
        'section'     => 'general',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'default_header_tab',
        'label'       => esc_html__( 'General', 'vital' ),
        'desc'        => '',
        'std'         => '',
        'type'        => 'tab',
        'section'     => 'header_options',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
	  array(
        'id'          => 'header_height',
        'label'       => esc_html__( 'Header height', 'vital' ),
		'desc'        => sprintf (esc_html_x( 'Set header height. Please add size units, e.g., %s', '%s stands for example value. Do not delete it.' ,'vital' ), '<code>70px</code>'),
        'std'         => '100px',
        'type'        => 'text',
        'section'     => 'header_options',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'sticky_header',
        'label'       => esc_html__( 'Sticky header', 'vital' ),
        'desc'        => esc_html__( 'Do you want a header to stick to top while you scroll?', 'vital' ),
        'std'         => 'sticky_header_smart',
        'type'        => 'radio',
        'section'     => 'header_options',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and',
        'choices'     => array( 
          array(
            'value'       => 'sticky_header_smart',
            'label'       => esc_html__( 'Smart header (sticky only when scrolling up)', 'vital' ),
            'src'         => ''
          ),
          array(
            'value'       => 'sticky_header',
            'label'       => esc_html__( 'Always sticky header', 'vital' ),
            'src'         => ''
          ),
          array(
            'value'       => 'no_sticky',
            'label'       => esc_html__( 'Disable sticky header', 'vital' ),
            'src'         => ''
          )
        )
      ),
      array(
        'id'          => 'header_style',
        'label'       => esc_html__( 'Header layout', 'vital' ),
		'desc'        => '',
        'std'         => 'default',
        'type'        => 'radio-image',
        'section'     => 'header_options',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ), 
      array(
        'id'          => 'header_width',
        'label'       => esc_html__( 'Full width header', 'vital' ),
        'desc'        => esc_html__( 'If not active, header will be the same width as your chosen content width.', 'vital' ),
        'std'         => 'off',
        'type'        => 'on-off',
        'section'     => 'header_options',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),	  
	  array(
        'id'          => 'menu_align',
        'label'       => esc_html__( 'Primary menu align', 'vital' ),
		'desc'        => '',
        'std'         => 'left',
        'type'        => 'select',
        'section'     => 'header_options',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => 'header_style:is(default)',
        'operator'    => 'and',
        'choices'     => array( 
          array(
            'value'       => 'left',
            'label'       => esc_html__( 'Left', 'vital' ),
            'src'         => ''
          ),
          array(
            'value'       => 'right',
            'label'       => esc_html__( 'Right', 'vital' ),
            'src'         => ''
          )
        )
      ),
      array(
        'id'          => 'header_bg',
        'label'       => esc_html__( 'Header background color', 'vital' ),
        'desc'        => esc_html__( 'Choose your site header color.', 'vital' ),
        'std'         => '#ffffff',
        'type'        => 'colorpicker_opacity',
        'section'     => 'header_options',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
	  array(
        'id'          => 'header_border',
        'label'       => esc_html__( 'Header shadow line', 'vital' ),
        'desc'        => esc_html__( 'Adds bottom shadow line to the default header.', 'vital' ),
        'std'         => 'on',
        'type'        => 'on-off',
        'section'     => 'header_options',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
	  array(
        'id'          => 'search_button',
        'label'       => esc_html__( 'Search button in menu', 'vital' ),
        'desc'        => esc_html__( 'Enables or disables search from menu.', 'vital' ),
        'std'         => 'on',
        'type'        => 'on-off',
        'section'     => 'header_options',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'cart_button',
        'label'       => esc_html__( 'WooCommerce cart button in menu', 'vital' ),
        'desc'        => esc_html__( 'Do you want a smart WooCommerce cart icon in main menu?', 'vital' ),
        'std'         => 'on',
        'type'        => 'on-off',
        'section'     => 'header_options',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'logo_tab',
        'label'       => esc_html__( 'Logo', 'vital' ),
        'desc'        => '',
        'std'         => '',
        'type'        => 'tab',
        'section'     => 'header_options',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'logo',
        'label'       => esc_html__( 'Logo', 'vital' ),
        'desc'        => esc_html__( 'Please choose an image file for your logo.', 'vital' ),
        'std'         => '',
        'type'        => 'upload',
        'section'     => 'header_options',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'logo_retina',
        'label'       => esc_html__( 'Logo (Retina version @2x)', 'vital' ),
		'desc'        => sprintf (esc_html_x( 'Retina logo should be %s the size of default logo keeping the aspect ratio!', '%s stands for the value. Do not delete it.' ,'vital' ), '<code>2x</code>'),
        'std'         => '',
        'type'        => 'upload',
        'section'     => 'header_options',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'retina_logo_width',
        'label'       => esc_html__( 'Standard logo width', 'vital' ),
		'desc'        => sprintf (esc_html_x( 'Please enter the STANDARD (1x) logo width. %1$s Remember to add %2$s value in the end. Example: %3$s', '%1$s stands for line break, %2$s and %3$s stand for example value.' ,'vital' ), '<br/>', '<code>px</code>', '<code>100px</code>'),
        'std'         => '',
        'type'        => 'text',
        'section'     => 'header_options',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'retina_logo_height',
        'label'       => esc_html__( 'Standard logo height', 'vital' ),
		'desc'        => sprintf (esc_html_x( 'Please enter the STANDARD (1x) logo height. %1$s Remember to add %2$s value in the end. Example: %3$s', '%1$s stands for line break, %2$s and %3$s stand for example value.' ,'vital' ), '<br/>', '<code>px</code>', '<code>100px</code>'),
        'std'         => '',
        'type'        => 'text',
        'section'     => 'header_options',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'logo_top',
        'label'       => esc_html__( 'Margin top', 'vital' ),
		'desc'        => sprintf (esc_html_x( 'Move your logo vertically with this option. Remember to add %1$s value after the number. For example: %2$s', '%1$s and %2$s stand for example value. Do not delete it.' ,'vital' ), '<code>px</code>', '<code>25px</code>'),
        'std'         => '',
        'type'        => 'text',
        'section'     => 'header_options',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
	  array(
        'id'          => 'overlay_header_tab',
        'label'       => esc_html__( 'Overlay Header', 'vital' ),
        'desc'        => '',
        'std'         => '',
        'type'        => 'tab',
        'section'     => 'header_options',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
	  array(
        'id'          => 'overlay_header_height',
        'label'       => esc_html__( 'Overlay header height', 'vital' ),
		'desc'        => sprintf (esc_html_x('Set header height. Please add size units, e.g., %s', '%s stands for example value. Do not delete it.' ,'vital' ), '<code>70px</code>'),
        'std'         => '',
        'type'        => 'text',
        'section'     => 'header_options',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
	  array(
        'id'          => 'detached_overlay_header',
        'label'       => esc_html__( 'Detached header?', 'vital' ),
        'desc'        => esc_html__( 'Detaches header from top and applies boxed style to it.', 'vital' ),
        'std'         => 'off',
        'type'        => 'on-off',
        'section'     => 'header_options',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'detached_overlay_header_background',
        'label'       => esc_html__( 'Deteached overlay header background color', 'vital' ),
        'desc'        => esc_html__( 'White by default.', 'vital' ),
        'std'         => '#ffffff',
        'type'        => 'colorpicker_opacity',
        'section'     => 'header_options',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => 'detached_overlay_header:is(on)',
        'operator'    => 'and'
      ),
	  array(
        'id'          => 'overlay_header_bg',
        'label'       => esc_html__( 'Overlay header background color', 'vital' ),
        'desc'        => esc_html__( 'Transparent by default.', 'vital' ),
        'std'         => '',
        'type'        => 'colorpicker_opacity',
        'section'     => 'header_options',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => 'detached_overlay_header:not(on)',
        'operator'    => 'and'
      ),
	  array(
        'id'          => 'overlay_sticky_menu_bg',
        'label'       => esc_html__( 'Sticky menu background color', 'vital' ),
        'desc'        => esc_html__( 'Sticky menu background should contrast menu link color.', 'vital' ),
        'std'         => '#3498db',
        'type'        => 'colorpicker_opacity',
        'section'     => 'header_options',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => 'detached_overlay_header:not(on)',
        'operator'    => 'and'
      ), 
	  array(
        'id'          => 'overlay_logo',
        'label'       => esc_html__( 'Overlay header logo', 'vital' ),
        'desc'        => esc_html__( 'Please choose an image file for your logo.', 'vital' ),
        'std'         => '',
        'type'        => 'upload',
        'section'     => 'header_options',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'overlay_logo_retina',
        'label'       => esc_html__( 'Overlay header logo (Retina version @2x)', 'vital' ),
		'desc'        => sprintf (esc_html_x( 'Retina logo should be %s the size of default logo keeping the aspect ratio!', '%s stands for the value. Do not delete it.' ,'vital' ), '<code>2x</code>'),
        'std'         => '',
        'type'        => 'upload',
        'section'     => 'header_options',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
	  array(
        'id'          => 'overlay_retina_logo_width',
        'label'       => esc_html__( 'Overlay header logo width', 'vital' ),
		'desc'        => sprintf (esc_html_x( 'Please enter the STANDARD (1x) overlay logo width. %1$s Remember to add %2$s value in the end. Example: %3$s', '%1$s stands for line break, %2$s and %3$s stand for example value.' ,'vital' ), '<br/>', '<code>px</code>', '<code>100px</code>'),
        'std'         => '',
        'type'        => 'text',
        'section'     => 'header_options',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'overlay_retina_logo_height',
        'label'       => esc_html__( 'Overlay header logo height', 'vital' ),
		'desc'        => sprintf (esc_html_x( 'Please enter the STANDARD (1x) overlay logo height. %1$s Remember to add %2$s value in the end. Example: %3$s', '%1$s stands for line break, %2$s and %3$s stand for example value.' ,'vital' ), '<br/>', '<code>px</code>', '<code>100px</code>'),
        'std'         => '',
        'type'        => 'text',
        'section'     => 'header_options',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
	  array(
        'id'          => 'overlay_logo_top',
        'label'       => esc_html__( 'Overlay header logo margin top', 'vital' ),
		'desc'        => sprintf (esc_html_x( 'Move your logo vertically with this option. Remember to add %1$s value after the number. For example: %2$s', '%1$s and %2$s stand for example value. Do not delete it.' ,'vital' ), '<code>px</code>', '<code>25px</code>'),
        'std'         => '',
        'type'        => 'text',
        'section'     => 'header_options',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'top_bar_tab',
        'label'       => esc_html__( 'Top Bar', 'vital' ),
        'desc'        => '',
        'std'         => '',
        'type'        => 'tab',
        'section'     => 'header_options',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'top_bar',
        'label'       => esc_html__( 'Top bar', 'vital' ),
        'desc'        => esc_html__( 'Top bar appears above the header. If activated, new widget areas appear in Appearance/Widgets - "Top Bar Sidebar Left" and "Top Bar Sidebar Right".', 'vital' ),
        'std'         => 'on',
        'type'        => 'on-off',
        'section'     => 'header_options',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'top_bar_bg',
        'label'       => esc_html__( 'Background color', 'vital' ),
        'desc'        => esc_html__( 'Click input field for color picker or enter your custom value.', 'vital' ),
        'std'         => '#f6f7f8',
        'type'        => 'colorpicker_opacity',
        'section'     => 'header_options',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => 'top_bar:is(on)',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'top_bar_text_color',
        'label'       => esc_html__( 'Text and link color', 'vital' ),
        'desc'        => esc_html__( 'Click input field for color picker or enter your custom value.', 'vital' ),
        'std'         => '#0b3b5b',
        'type'        => 'colorpicker_opacity',
        'section'     => 'header_options',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => 'top_bar:is(on)',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'top_bar_link_hover',
        'label'       => esc_html__( 'Link hover color', 'vital' ),
        'desc'        => esc_html__( 'Click input field for color picker or enter your custom value.', 'vital' ),
        'std'         => '#3498db',
        'type'        => 'colorpicker_opacity',
        'section'     => 'header_options',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => 'top_bar:is(on)',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'mobile_header_tab',
        'label'       => esc_html__( 'Mobile Header', 'vital' ),
        'desc'        => '',
        'std'         => '',
        'type'        => 'tab',
        'section'     => 'header_options',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'mobile_menu_background',
        'label'       => esc_html__( 'Mobile menu background color', 'vital' ),
        'desc'        => esc_html__( 'Choose background color for mobile menu.', 'vital' ),
        'std'         => '#ffffff',
        'type'        => 'colorpicker_opacity',
        'section'     => 'header_options',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'mobile_menu_toggle_color',
        'label'       => esc_html__( 'Mobile menu toggle color', 'vital' ),
        'desc'        => esc_html__( 'Choose color for mobile menu toggle icon.', 'vital' ),
        'std'         => '#0b3b5b',
        'type'        => 'colorpicker_opacity',
        'section'     => 'header_options',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'mobile_logo',
        'label'       => esc_html__( 'Mobile logo', 'vital' ),
        'desc'        => esc_html__( 'Please choose an image file for your logo.', 'vital' ),
        'std'         => '',
        'type'        => 'upload',
        'section'     => 'header_options',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'mobile_logo_retina',
        'label'       => esc_html__( 'Mobile Logo (Retina version @2x)', 'vital' ),
		'desc'        => sprintf (esc_html_x( 'Retina logo should be %s the size of default logo keeping the aspect ratio!', '%s stands for the value. Do not delete it.' ,'vital' ), '<code>2x</code>'),
        'std'         => '',
        'type'        => 'upload',
        'section'     => 'header_options',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'mobile_retina_logo_width',
        'label'       => esc_html__( 'Mobile logo width', 'vital' ),
		'desc'        => sprintf (esc_html_x( 'Please enter the STANDARD (1x) logo width. %1$s Remember to add %2$s value in the end. Example: %3$s', '%1$s stands for line break, %2$s and %3$s stand for example value.' ,'vital' ), '<br/>', '<code>px</code>', '<code>100px</code>'),
        'std'         => '',
        'type'        => 'text',
        'section'     => 'header_options',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'mobile_retina_logo_height',
        'label'       => esc_html__( 'Mobile logo height', 'vital' ),
		'desc'        => sprintf (esc_html_x( 'Please enter the STANDARD (1x) logo height. %1$s Remember to add %2$s value in the end. Example: %3$s', '%1$s stands for line break, %2$s and %3$s stand for example value.' ,'vital' ), '<br/>', '<code>px</code>', '<code>100px</code>'),
        'std'         => '',
        'type'        => 'text',
        'section'     => 'header_options',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),	
      array(
        'id'          => 'navigation_tab',
        'label'       => esc_html__( 'Header Menu', 'vital' ),
        'desc'        => '',
        'std'         => '',
        'type'        => 'tab',
        'section'     => 'navigation_options',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
		'condition'   => '',
        'operator'    => 'and'
      ),	  
      array(
        'id'          => 'default_menu_link',
        'label'       => esc_html__( 'Menu link color', 'vital' ),
        'desc'        => esc_html__( 'Click input field for color picker or enter your custom value.', 'vital' ),
        'std'         => '#646c84',
        'type'        => 'colorpicker_opacity',
        'section'     => 'navigation_options',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'default_menu_link_h',
        'label'       => esc_html__( 'Menu link hover & active color', 'vital' ),
        'desc'        => esc_html__( 'Leave empty to use "Theme accent color".', 'vital' ),
        'std'         => '',
        'type'        => 'colorpicker_opacity',
        'section'     => 'navigation_options',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'show_submenu_styles',
        'label'       => esc_html__( 'Show submenu options?', 'vital' ),
        'desc'        => esc_html__( 'Enable submenu styling.', 'vital' ),
        'std'         => 'off',
        'type'        => 'on-off',
        'section'     => 'navigation_options',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'submenu_section_info',
        'label'       => esc_html__( 'Submenu section info', 'vital' ),
        'desc'        => esc_html__( '<div class="section-title">Submenu options</div>', 'vital' ),
        'std'         => '',
        'type'        => 'textblock',
        'section'     => 'navigation_options',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => 'show_submenu_styles:is(on)',
        'operator'    => 'and'
      ),
	  array(
        'id'          => 'submenu_background',
        'label'       => esc_html__( 'Submenu background color', 'vital' ),
        'desc'        => esc_html__( 'Color background color for submenu.', 'vital' ),
        'std'         => '',
        'type'        => 'colorpicker_opacity',
        'section'     => 'navigation_options',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => 'show_submenu_styles:is(on)',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'submenu_link_color',
        'label'       => esc_html__( 'Submenu link color', 'vital' ),
        'desc'        => esc_html__( 'Color for links in submenu.', 'vital' ),
        'std'         => '',
        'type'        => 'colorpicker_opacity',
        'section'     => 'navigation_options',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => 'show_submenu_styles:is(on)',
        'operator'    => 'and'
      ),
	  array(
        'id'          => 'submenu_link_bg_color',
        'label'       => esc_html__( 'Submenu link hover & active background color', 'vital' ),
        'desc'        => esc_html__( 'Background color for submenu link hover.', 'vital' ),
        'std'         => '',
        'type'        => 'colorpicker_opacity',
        'section'     => 'navigation_options',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => 'show_submenu_styles:is(on)',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'megamenu_section_info',
        'label'       => esc_html__( 'Megamenu section info', 'vital' ),
		'desc'        => '<div class="section-title">'. esc_html__( 'Mega-menu options', 'vital' ) .'</div>',
        'std'         => '',
        'type'        => 'textblock',
        'section'     => 'navigation_options',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => 'show_submenu_styles:is(on)',
        'operator'    => 'and'
      ),
	  array(
        'id'          => 'megamenu_bg',
        'label'       => esc_html__( 'Background', 'vital' ),
        'desc'        => esc_html__( 'You can either use color or upload a background image. Leave blank for default setting.', 'vital' ),
        'std'         => '',
        'type'        => 'background',
        'section'     => 'navigation_options',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => 'show_submenu_styles:is(on)',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'megamenu_title_color',
        'label'       => esc_html__( 'Megamenu title color', 'vital' ),
        'desc'        => esc_html__( 'Color for column title inside megamenu.', 'vital' ),
        'std'         => '',
        'type'        => 'colorpicker_opacity',
        'section'     => 'navigation_options',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => 'show_submenu_styles:is(on)',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'megamenu_active_item_color',
        'label'       => esc_html__( 'Megamenu hover & active item color', 'vital' ),
        'desc'        => esc_html__( 'Leave empty to use "Theme accent color".', 'vital' ),
        'std'         => '',
        'type'        => 'colorpicker_opacity',
        'section'     => 'navigation_options',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => 'show_submenu_styles:is(on)',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'megamenu_separator_color',
        'label'       => esc_html__( 'Megamenu column separator color', 'vital' ),
        'desc'        => esc_html__( 'Leave empty for default color.', 'vital' ),
        'std'         => '',
        'type'        => 'colorpicker_opacity',
        'section'     => 'navigation_options',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => 'show_submenu_styles:is(on)',
        'operator'    => 'and'
      ),
	  array(
        'id'          => 'overlay_menu_navigation_tab',
        'label'       => esc_html__( 'Overlay Header Menu', 'vital' ),
        'desc'        => '',
        'std'         => '',
        'type'        => 'tab',
        'section'     => 'navigation_options',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
		'condition'   => '',
        'operator'    => 'and'
      ),
	  array(
        'id'          => 'overlay_menu_link',
        'label'       => esc_html__( 'Overlay header menu link color', 'vital' ),
        'desc'        => esc_html__( 'Click input field for color picker or enter your custom value.', 'vital' ),
        'std'         => '#ffffff',
        'type'        => 'colorpicker_opacity',
        'section'     => 'navigation_options',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'overlay_menu_link_h',
        'label'       => esc_html__( 'Overlay header menu link hover & active color', 'vital' ),
        'desc'        => esc_html__( 'Leave empty to use "Theme accent color".', 'vital' ),
        'std'         => 'rgba(255,255,255,0.77)',
        'type'        => 'colorpicker_opacity',
        'section'     => 'navigation_options',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),     
	  array(
        'id'          => 'side_navigation_tab',
        'label'       => esc_html__( 'Side Menu', 'vital' ),
        'desc'        => '',
        'std'         => '',
        'type'        => 'tab',
        'section'     => 'navigation_options',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
		'condition'   => '',
        'operator'    => 'and'
      ),
	  array(
        'id'          => 'side_navigation_bg',
        'label'       => esc_html__( 'Background', 'vital' ),
        'desc'        => esc_html__( 'You can either use color or upload a background image. Leave blank for default setting.', 'vital' ),
        'std'         => '',
        'type'        => 'background',
        'section'     => 'navigation_options',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
	  array(
        'id'          => 'side_navigation_border',
        'label'       => esc_html__( 'Border color', 'vital' ),
        'desc'        => esc_html__( 'Choose side border color for side navigation.', 'vital' ),
        'std'         => '',
        'type'        => 'colorpicker_opacity',
        'section'     => 'navigation_options',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
	  array(
        'id'          => 'side_navigation_link',
        'label'       => esc_html__( 'Link and text color', 'vital' ),
        'desc'        => esc_html__( 'Choose color for side navigation links and text.', 'vital' ),
        'std'         => '',
        'type'        => 'colorpicker_opacity',
        'section'     => 'navigation_options',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
	  array(
        'id'          => 'side_navigation_link_hover',
        'label'       => esc_html__( 'Link hover color', 'vital' ),
        'desc'        => esc_html__( 'Choose hover color for side navigation links.', 'vital' ),
        'std'         => '',
        'type'        => 'colorpicker_opacity',
        'section'     => 'navigation_options',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),	  
	  array(
        'id'          => 'overlay_navigation_tab',
        'label'       => esc_html__( 'Fullscreen Overlay Menu', 'vital' ),
        'desc'        => '',
        'std'         => '',
        'type'        => 'tab',
        'section'     => 'navigation_options',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
		'condition'   => '',
        'operator'    => 'and'
      ),
	  array(
        'id'          => 'overlay_navigation_bg',
        'label'       => esc_html__( 'Background', 'vital' ),
        'desc'        => esc_html__( 'You can either use color or upload a background image. Leave blank for default setting.', 'vital' ),
        'std'         => '',
        'type'        => 'background',
        'section'     => 'navigation_options',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
	  array(
        'id'          => 'overlay_navigation_link',
        'label'       => esc_html__( 'Link and text color', 'vital' ),
        'desc'        => esc_html__( 'Choose color for overlay navigation links and text.', 'vital' ),
        'std'         => '',
        'type'        => 'colorpicker_opacity',
        'section'     => 'navigation_options',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
	  array(
        'id'          => 'overlay_navigation_link_hover',
        'label'       => esc_html__( 'Link hover color', 'vital' ),
        'desc'        => esc_html__( 'Choose hover color for overlay navigation links.', 'vital' ),
        'std'         => '',
        'type'        => 'colorpicker_opacity',
        'section'     => 'navigation_options',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),	  
      array(
        'id'          => 'global_color_section',
        'label'       => esc_html__( 'Global', 'vital' ),
        'desc'        => '',
        'std'         => '',
        'type'        => 'tab',
        'section'     => 'color_options',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'body_text_color',
        'label'       => esc_html__( 'Body text color', 'vital' ),
        'desc'        => esc_html__( 'General color for all body content.', 'vital' ),
        'std'         => '#666677',
        'type'        => 'colorpicker_opacity',
        'section'     => 'color_options',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'headings_color',
        'label'       => esc_html__( 'Headings (H1, H2, H3, H4, H5, H6)', 'vital' ),
        'desc'        => esc_html__( 'Color for heading tags. Applies for all heading elements, if different color is not specified in element styling.', 'vital' ),
        'std'         => '#0b3b5b',
        'type'        => 'colorpicker_opacity',
        'section'     => 'color_options',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'link_color',
        'label'       => esc_html__( 'Link color', 'vital' ),
        'desc'        => esc_html__( 'Global link color.', 'vital' ),
        'std'         => '',
        'type'        => 'colorpicker_opacity',
        'section'     => 'color_options',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'link_hover_color',
        'label'       => esc_html__( 'Link hover color', 'vital' ),
        'desc'        => esc_html__( 'Global link hover color.', 'vital' ),
        'std'         => '',
        'type'        => 'colorpicker_opacity',
        'section'     => 'color_options',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'theme_button_color',
        'label'       => esc_html__( 'Theme button color', 'vital' ),
		'desc'        => sprintf (esc_html_x( 'Choose color for general theme buttons. %1$s Leave empty for "Theme accent Color"', '%1$s stands for line break' ,'vital' ), '<br/>'),
        'std'         => '',
        'type'        => 'colorpicker_opacity',
        'section'     => 'color_options',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'theme_button_hover_color',
        'label'       => esc_html__( 'Theme button hover color', 'vital' ),
        'desc'        => esc_html__( 'Choose color for theme buttons in hover state.', 'vital' ),
        'std'         => '',
        'type'        => 'colorpicker_opacity',
        'section'     => 'color_options',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'button_text_color',
        'label'       => esc_html__( 'Button Text Color', 'vital' ),
        'desc'        => esc_html__( 'Text color inside theme buttons.', 'vital' ),
        'std'         => '',
        'type'        => 'colorpicker_opacity',
        'section'     => 'color_options',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
	  array(
        'id'          => 'page_heading_tab',
        'label'       => esc_html__( 'Page Heading', 'vital' ),
        'desc'        => '',
        'std'         => '',
        'type'        => 'tab',
        'section'     => 'color_options',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
	  array(
        'id'          => 'page_title_text_color',
        'label'       => esc_html__( 'Title color', 'vital' ),
        'desc'        => esc_html__( 'Choose text color for page title.', 'vital' ),
        'std'         => '',
        'type'        => 'colorpicker_opacity',
        'section'     => 'color_options',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
	  array(
        'id'          => 'page_title_background',
        'label'       => esc_html__( 'Background color', 'vital' ),
        'desc'        => esc_html__( 'Choose background color for page title area.', 'vital' ),
        'std'         => '',
        'type'        => 'colorpicker_opacity',
        'section'     => 'color_options',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
	  array(
        'id'          => 'page_title_background_gradient',
        'label'       => esc_html__( 'Enable gradient background', 'vital' ),
        'desc'        => esc_html__( 'Enables left to right gradient background for page title area.', 'vital' ),
        'std'         => 'off',
        'type'        => 'on-off',
        'section'     => 'color_options',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'operator'    => 'and'
      ),
	  array(
        'id'          => 'page_title_background_gradient_start',
        'label'       => esc_html__( 'Gradient start color', 'vital' ),
        'desc'        => esc_html__( 'Choose color at gradient start.', 'vital' ),
        'std'         => '',
        'type'        => 'colorpicker_opacity',
        'section'     => 'color_options',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => 'page_title_background_gradient:is(on)',
        'operator'    => 'and'
      ),
	  array(
        'id'          => 'page_title_background_gradient_end',
        'label'       => esc_html__( 'Gradient end color', 'vital' ),
        'desc'        => esc_html__( 'Choose color at gradient end.', 'vital' ),
        'std'         => '',
        'type'        => 'colorpicker_opacity',
        'section'     => 'color_options',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => 'page_title_background_gradient:is(on)',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'sidebar_tab',
        'label'       => esc_html__( 'Sidebar', 'vital' ),
        'desc'        => '',
        'std'         => '',
        'type'        => 'tab',
        'section'     => 'color_options',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'sidebar_text_color',
        'label'       => esc_html__( 'Text color', 'vital' ),
        'desc'        => esc_html__( 'Choose text color for sidebar widget content.', 'vital' ),
        'std'         => '#666677',
        'type'        => 'colorpicker_opacity',
        'section'     => 'color_options',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'sidebar_link_color',
        'label'       => esc_html__( 'Link color', 'vital' ),
        'desc'        => esc_html__( 'Choose color for links in sidebar.', 'vital' ),
        'std'         => '',
        'type'        => 'colorpicker_opacity',
        'section'     => 'color_options',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'sidebar_link_hover_color',
        'label'       => esc_html__( 'Link hover color', 'vital' ),
        'desc'        => esc_html__( 'Leave empty to use "Theme accent color".', 'vital' ),
        'std'         => '',
        'type'        => 'colorpicker_opacity',
        'section'     => 'color_options',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'sidebar_title_color',
        'label'       => esc_html__( 'Widget title color', 'vital' ),
        'desc'        => esc_html__( 'Color for widget titles in sidebar.', 'vital' ),
        'std'         => '',
        'type'        => 'colorpicker_opacity',
        'section'     => 'color_options',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
	  array(
        'id'          => 'sidebar_title_border_color',
        'label'       => esc_html__( 'Title border color', 'vital' ),
        'desc'        => esc_html__( 'Choose color for sidebar title bottom border.', 'vital' ),
        'std'         => '',
        'type'        => 'colorpicker_opacity',
        'section'     => 'color_options',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'sidebar_divider_color',
        'label'       => esc_html__( 'Widget divider color', 'vital' ),
        'desc'        => esc_html__( 'Choose border line color separating list items in sidebar.', 'vital' ),
        'std'         => '',
        'type'        => 'colorpicker_opacity',
        'section'     => 'color_options',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'custom_fonts_tab',
        'label'       => esc_html__( 'Custom fonts', 'vital' ),
        'desc'        => '',
        'std'         => '',
        'type'        => 'tab',
        'section'     => 'typography',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'add_google_fonts',
        'label'       => esc_html__( 'Add Google fonts', 'vital' ),
		'desc'        => sprintf (esc_html_x( '1. Click "Add Google Font". %1$s 2. Choose your font and options. %1$s 3. Save the options. %1$s 4. Assign your new font to elements below.', '%1$s stands for line break' ,'vital' ), '<br/>'),
        'std'         => '',
        'type'        => 'google-fonts',
        'section'     => 'typography',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
	  array(
        'id'          => 'body_font',
        'label'       => esc_html__( 'Body font', 'vital' ),
        'desc'        => '',
        'std'         => '',
        'type'        => 'typography',
        'section'     => 'typography',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'menu_font',
        'label'       => esc_html__( 'Menu font', 'vital' ),
        'desc'        => '',
        'std'         => '',
        'type'        => 'typography',
        'section'     => 'typography',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
	  array(
        'id'          => 'overlay_side_menu_font',
        'label'       => esc_html__( 'Overlay or side menu font', 'vital' ),
        'desc'        => '',
        'std'         => '',
        'type'        => 'typography',
        'section'     => 'typography',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'heading_font',
        'label'       => esc_html__( 'Heading font', 'vital' ),
        'desc'        => '',
        'std'         => '',
        'type'        => 'typography',
        'section'     => 'typography',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'single_post_font',
        'label'       => esc_html__( 'Single post font', 'vital' ),
        'std'         => '',
        'type'        => 'typography',
        'section'     => 'typography',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'widget_font',
        'label'       => esc_html__( 'Widget title font', 'vital' ),
        'desc'        => '',
        'std'         => '',
        'type'        => 'typography',
        'section'     => 'typography',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'font_size_tab',
        'label'       => esc_html__( 'Font sizes', 'vital' ),
        'desc'        => '',
        'std'         => '',
        'type'        => 'tab',
        'section'     => 'typography',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'body_size',
        'label'       => esc_html__( 'Body', 'vital' ),
		'desc'        => sprintf (esc_html_x( 'General body font size. %1$s Remember to add %2$s px %3$s value after the number. For example: %2$s 16px %3$s', '%1$s stands for line break, %2$s and %3$s stand for <code> tags' ,'vital' ), '<br/>', '<code>', '</code>'),
        'std'         => '16px',
        'type'        => 'text',
        'section'     => 'typography',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'single_post_text_font_size',
        'label'       => esc_html__( 'Single post', 'vital' ),
		'desc'        => sprintf (esc_html_x( 'Single post content font size. %1$s Remember to add %2$s px %3$s value after the number. For example: %2$s 16px %3$s', '%1$s stands for line break, %2$s and %3$s stand for <code> tags' ,'vital' ), '<br/>', '<code>', '</code>'),
        'std'         => '16px',
        'type'        => 'text',
        'section'     => 'typography',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'menu_font_size',
        'label'       => esc_html__( 'Menu in header bar', 'vital' ),
		'desc'        => sprintf (esc_html_x( 'General menu font size. %1$s Remember to add %2$s px %3$s value after the number. For example: %2$s 13px %3$s', '%1$s stands for line break, %2$s and %3$s stand for <code> tags' ,'vital' ), '<br/>', '<code>', '</code>'),
        'std'         => '15px',
        'type'        => 'text',
        'section'     => 'typography',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
	  array(
        'id'          => 'side_overlay_menu_font_size',
        'label'       => esc_html__( 'Overlay or side menu (optional)', 'vital' ),
		'desc'        => sprintf (esc_html_x( 'Choose size for overlay or side menu, depending on what you use. %1$s Remember to add %2$s px %3$s value after the number. For example: %2$s 13px %3$s', '%1$s stands for line break, %2$s and %3$s stand for <code> tags' ,'vital' ), '<br/>', '<code>', '</code>'),
        'std'         => '',
        'type'        => 'text',
        'section'     => 'typography',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'sub_menu_font_size',
        'label'       => esc_html__( 'Sub menu', 'vital' ),
		'desc'        => sprintf (esc_html_x( 'Submenu link font size. %1$s Remember to add %2$s px %3$s value after the number.', '%1$s stands for line break, %2$s and %3$s stand for <code> tags' ,'vital' ), '<br/>', '<code>', '</code>'),
        'std'         => '13px',
        'type'        => 'text',
        'section'     => 'typography',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'h1',
        'label'       => esc_html__( 'H1', 'vital' ),
		'desc'        => sprintf (esc_html_x( 'Heading 1 tag font size. %1$s Remember to add %2$s px %3$s value after the number.', '%1$s stands for line break, %2$s and %3$s stand for <code> tags' ,'vital' ), '<br/>', '<code>', '</code>'),
        'std'         => '30px',
        'type'        => 'text',
        'section'     => 'typography',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'h2',
        'label'       => esc_html__( 'H2', 'vital' ),
		'desc'        => sprintf (esc_html_x( 'Heading 2 tag font size. %1$s Remember to add %2$s px %3$s value after the number.', '%1$s stands for line break, %2$s and %3$s stand for <code> tags' ,'vital' ), '<br/>', '<code>', '</code>'),
        'std'         => '24px',
        'type'        => 'text',
        'section'     => 'typography',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'h3',
        'label'       => esc_html__( 'H3', 'vital' ),
		'desc'        => sprintf (esc_html_x( 'Heading 3 tag font size. %1$s Remember to add %2$s px %3$s value after the number.', '%1$s stands for line break, %2$s and %3$s stand for <code> tags' ,'vital' ), '<br/>', '<code>', '</code>'),
        'std'         => '20px',
        'type'        => 'text',
        'section'     => 'typography',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'h4',
        'label'       => esc_html__( 'H4', 'vital' ),
		'desc'        => sprintf (esc_html_x( 'Heading 4 tag font size. %1$s Remember to add %2$s px %3$s value after the number.', '%1$s stands for line break, %2$s and %3$s stand for <code> tags' ,'vital' ), '<br/>', '<code>', '</code>'),
        'std'         => '18px',
        'type'        => 'text',
        'section'     => 'typography',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'h5',
        'label'       => esc_html__( 'H5', 'vital' ),
		'desc'        => sprintf (esc_html_x( 'Heading 5 tag font size. %1$s Remember to add %2$s px %3$s value after the number.', '%1$s stands for line break, %2$s and %3$s stand for <code> tags' ,'vital' ), '<br/>', '<code>', '</code>'),
        'std'         => '16px',
        'type'        => 'text',
        'section'     => 'typography',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'h6',
        'label'       => esc_html__( 'H6', 'vital' ),
		'desc'        => sprintf (esc_html_x( 'Heading 6 tag font size. %1$s Remember to add %2$s px %3$s value after the number.', '%1$s stands for line break, %2$s and %3$s stand for <code> tags' ,'vital' ), '<br/>', '<code>', '</code>'),
        'std'         => '14px',
        'type'        => 'text',
        'section'     => 'typography',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'footer_tab',
        'label'       => esc_html__( 'Footer', 'vital' ),
        'desc'        => '',
        'std'         => '',
        'type'        => 'tab',
        'section'     => 'footer_options',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'footer_columns',
        'label'       => esc_html__( 'Column count', 'vital' ),
        'desc'        => esc_html__( 'Choose column count for your footer.', 'vital' ),
        'std'         => 'vc_col-sm-3',
        'type'        => 'select',
        'section'     => 'footer_options',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and',
        'choices'     => array( 
          array(
            'value'       => 'vc_col-sm-12',
            'label'       => esc_html__( '1', 'vital' ),
            'src'         => ''
          ),
          array(
            'value'       => 'vc_col-sm-6',
            'label'       => esc_html__( '2', 'vital' ),
            'src'         => ''
          ),
          array(
            'value'       => 'vc_col-sm-4',
            'label'       => esc_html__( '3', 'vital' ),
            'src'         => ''
          ),
          array(
            'value'       => 'vc_col-sm-3',
            'label'       => esc_html__( '4', 'vital' ),
            'src'         => ''
          )
        )
      ),
      array(
        'id'          => 'footer_column_1_width',
        'label'       => esc_html__( 'Footer column 1 width', 'vital' ),
		'desc'        => sprintf (esc_html_x( 'Enter custom width for first footer column. Please enter percentage, e.g., %s', '%s stands for example value. Do not delete it.' ,'vital' ), '<code>50%</code>'),
        'std'         => '20%',
        'type'        => 'text',
        'section'     => 'footer_options',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => 'footer_columns:not(vc_col-sm-12)',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'footer_column_2_width',
        'label'       => esc_html__( 'Footer column 2 width', 'vital' ),
		'desc'        => sprintf (esc_html_x( 'Enter custom width for second footer column. Please enter percentage, e.g., %s', '%s stands for example value. Do not delete it.' ,'vital' ), '<code>50%</code>'),
        'std'         => '20%',
        'type'        => 'text',
        'section'     => 'footer_options',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => 'footer_columns:not(vc_col-sm-12)',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'footer_column_3_width',
        'label'       => esc_html__( 'Footer column 3 width', 'vital' ),
		'desc'        => sprintf (esc_html_x( 'Enter custom width for third footer column. Please enter percentage, e.g., %s', '%s stands for example value. Do not delete it.' ,'vital' ), '<code>50%</code>'),
        'std'         => '20%',
        'type'        => 'text',
        'section'     => 'footer_options',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => 'footer_columns:not(vc_col-sm-12),footer_columns:not(vc_col-sm-6)',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'footer_column_4_width',
        'label'       => esc_html__( 'Footer column 4 width', 'vital' ),
		'desc'        => sprintf (esc_html_x( 'Enter custom width for fourth footer column. Please enter percentage, e.g., %s', '%s stands for example value. Do not delete it.' ,'vital' ), '<code>50%</code>'),
        'std'         => '40%',
        'type'        => 'text',
        'section'     => 'footer_options',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => 'footer_columns:is(vc_col-sm-3)',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'footer_bg',
        'label'       => esc_html__( 'Background', 'vital' ),
        'desc'        => esc_html__( 'You can either use color or upload a background image. Leave blank for default setting.', 'vital' ),
        'std'         => '',
        'type'        => 'background',
        'section'     => 'footer_options',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'footer_text_color',
        'label'       => esc_html__( 'Text color', 'vital' ),
        'desc'        => esc_html__( 'Choose text color for your footer widget content.', 'vital' ),
        'std'         => '',
        'type'        => 'colorpicker_opacity',
        'section'     => 'footer_options',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'footer_link',
        'label'       => esc_html__( 'Link color', 'vital' ),
        'desc'        => esc_html__( 'Will apply color to all links located in footer widgets.', 'vital' ),
        'std'         => '',
        'type'        => 'colorpicker_opacity',
        'section'     => 'footer_options',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'footer_link_hover',
        'label'       => esc_html__( 'Link hover color', 'vital' ),
        'desc'        => esc_html__( 'Leave empty to use "Theme accent color".', 'vital' ),
        'std'         => '',
        'type'        => 'colorpicker_opacity',
        'section'     => 'footer_options',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'footer_widget_title',
        'label'       => esc_html__( 'Widget title color', 'vital' ),
        'desc'        => esc_html__( 'Color for widget titles in footer.', 'vital' ),
        'std'         => '',
        'type'        => 'colorpicker_opacity',
        'section'     => 'footer_options',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'copyright_tab',
        'label'       => esc_html__( 'Copyright', 'vital' ),
        'desc'        => '',
        'std'         => '',
        'type'        => 'tab',
        'section'     => 'footer_options',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
	   array(
        'id'          => 'copyright_text_align',
        'label'       => esc_html__( 'Text align', 'vital' ),
        'desc'        => esc_html__( 'Text align for widgets in copyright area.', 'vital' ),
        'std'         => 'center',
        'type'        => 'select',
        'section'     => 'footer_options',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and',
        'choices'     => array( 
          array(
            'value'       => 'left',
            'label'       => esc_html__( 'Left', 'vital' ),
            'src'         => ''
          ),
          array(
            'value'       => 'center',
            'label'       => esc_html__( 'Center', 'vital' ),
            'src'         => ''
          ),
          array(
            'value'       => 'right',
            'label'       => esc_html__( 'Right', 'vital' ),
            'src'         => ''
          )
        )
      ),
      array(
        'id'          => 'copyright_bg',
        'label'       => esc_html__( 'Background', 'vital' ),
        'desc'        => esc_html__( 'You can either use color or upload a background image. Leave blank for default setting.', 'vital' ),
        'std'         => '',
        'type'        => 'background',
        'section'     => 'footer_options',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
	  array(
        'id'          => 'copyright_separator_color',
        'label'       => esc_html__( 'Separator color', 'vital' ),
        'desc'        => esc_html__( 'Choose color for copyright area separator.', 'vital' ),
        'std'         => '',
        'type'        => 'colorpicker_opacity',
        'section'     => 'footer_options',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'copyright_text_color',
        'label'       => esc_html__( 'Text color', 'vital' ),
        'desc'        => esc_html__( 'Choose text color for your copyright area widget content.', 'vital' ),
        'std'         => '',
        'type'        => 'colorpicker_opacity',
        'section'     => 'footer_options',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'copyright_link',
        'label'       => esc_html__( 'Link color', 'vital' ),
        'desc'        => esc_html__( 'Color for links located in your copyright area widgets.', 'vital' ),
        'std'         => '',
        'type'        => 'colorpicker_opacity',
        'section'     => 'footer_options',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'copyright_link_hover',
        'label'       => esc_html__( 'Link hover color', 'vital' ),
        'desc'        => esc_html__( 'Leave empty to use "Theme accent color".', 'vital' ),
        'std'         => '',
        'type'        => 'colorpicker_opacity',
        'section'     => 'footer_options',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'mnky_post_width',
        'label'       => esc_html__( 'Set different width for paragraphs', 'vital' ),
        'desc'        => esc_html__( 'Specify maximum width for text paragraphs without affecting other content , e.g., images.', 'vital' ),
        'std'         => '',
        'type'        => 'text',
        'section'     => 'articles_section',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),	  
	   array(
        'id'          => 'read_more_open_top',
        'label'       => esc_html__( 'Open read more links from top', 'vital' ),
        'desc'        => esc_html__( 'Makes read more link open post at the top', 'vital' ),
        'std'         => 'off',
        'type'        => 'on-off',
        'section'     => 'articles_section',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'post_category',
        'label'       => esc_html__( 'Show post category', 'vital' ),
        'desc'        => esc_html__( 'Do you want to display category in post meta fields?', 'vital' ),
        'std'         => 'on',
        'type'        => 'on-off',
        'section'     => 'articles_section',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'post_author',
        'label'       => esc_html__( 'Post author in meta', 'vital' ),
        'desc'        => esc_html__( 'Do you want to display author in post meta fields?', 'vital' ),
        'std'         => 'on',
        'type'        => 'on-off',
        'section'     => 'articles_section',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'post_date',
        'label'       => esc_html__( 'Post date in meta', 'vital' ),
        'desc'        => esc_html__( 'Do you want to display date in post meta fields?', 'vital' ),
        'std'         => 'on',
        'type'        => 'on-off',
        'section'     => 'articles_section',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'post_comments',
        'label'       => esc_html__( 'Comments link in meta', 'vital' ),
        'desc'        => esc_html__( 'Do you want to display comment count in post meta fields?', 'vital' ),
        'std'         => 'on',
        'type'        => 'on-off',
        'section'     => 'articles_section',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'post_links',
        'label'       => esc_html__( 'Previous &amp; next post link', 'vital' ),
        'desc'        => esc_html__( 'Do you want to display next and previous post links on single blog post page?', 'vital' ),
        'std'         => 'on',
        'type'        => 'on-off',
        'section'     => 'articles_section',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'post_tags',
        'label'       => esc_html__( 'Post tags after content', 'vital' ),
        'desc'        => esc_html__( 'Display post tags on single post page?', 'vital' ),
        'std'         => 'on',
        'type'        => 'on-off',
        'section'     => 'articles_section',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'author_description',
        'label'       => esc_html__( 'Post author description after content', 'vital' ),
        'desc'        => esc_html__( 'When ON, author info box will only appear for those post authors who have "Biographical Info" field filled!', 'vital' ),
        'std'         => 'on',
        'type'        => 'on-off',
        'section'     => 'articles_section',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
	  array(
        'id'          => 'blog_layout',
        'label'       => esc_html__( 'Blog page layout', 'vital' ),
		'desc'        => sprintf (esc_html_x( '1. Full width content %1$s 2. Content / Right sidebar %1$s 3. Content / Left sidebar', '%1$s stands for line break' ,'vital' ), '<br/>'),
        'std'         => 'right-sidebar',
        'type'        => 'radio-image',
        'section'     => 'blog_section',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'archive_post_style',
        'label'       => esc_html__( 'Post style', 'vital' ),
        'desc'        => esc_html__( 'Choose your post style.', 'vital' ),
        'std'         => '1',
        'type'        => 'select',
        'section'     => 'blog_section',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and',
        'choices'     => array( 
          array(
            'value'       => '1',
            'label'       => esc_html__( 'Default', 'vital' ),
            'src'         => ''
          ),
          array(
            'value'       => '2',
            'label'       => esc_html__( 'Image overlay', 'vital' ),
            'src'         => ''
          )         
        )
      ),
      array(
        'id'          => 'archive_post_layout',
        'label'       => esc_html__( 'Post layout', 'vital' ),
		'desc'        => sprintf (esc_html_x( '1. One column %1$s 2. Two column', '%1$s stands for line break' ,'vital' ), '<br/>'),
        'std'         => 'layout-one-column',
        'type'        => 'radio-image',
        'section'     => 'blog_section',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'or'
      ),
      array(
        'id'          => 'blog_title',
        'label'       => esc_html__( 'Blog title', 'vital' ),
        'desc'        => esc_html__( 'Choose whether to display or hide blog title.', 'vital' ),
        'std'         => 'on',
        'type'        => 'on-off',
        'section'     => 'blog_section',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'blog_pre_content_area',
        'label'       => esc_html__( 'Pre-content area', 'vital' ),
        'desc'        => esc_html__( 'Activates additional area before main content.', 'vital' ),
        'std'         => 'off',
        'type'        => 'on-off',
        'section'     => 'blog_section',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'blog_pre_content_height',
        'label'       => esc_html__( 'Height (optional)', 'vital' ),
		'desc'        => sprintf (esc_html_x( 'Pre-content area height. Example: %s', '%s stands for example value. Do not delete it.' ,'vital' ), '<code>250px</code>'),
        'std'         => '',
        'type'        => 'text',
        'section'     => 'blog_section',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => 'child-options child-first',
        'condition'   => 'blog_pre_content_area:is(on)',
        'operator'    => 'and'
      ),
	  array(
        'id'          => 'blog_pre_content_responsive_height',
        'label'       => esc_html__( 'Responsive height (optional)', 'vital' ),
        'desc'        => esc_html__( 'Enables auto height in responsive mode.', 'vital' ),
        'std'         => 'off',
        'type'        => 'on-off',
        'section'     => 'blog_section',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => 'child-options',
        'condition'   => 'blog_pre_content_area:is(on)',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'blog_pre_content_width',
        'label'       => esc_html__( 'Max width (optional)', 'vital' ),
		'desc'        => sprintf (esc_html_x( 'Pre-content area max width. Example: %s', '%s stands for example value. Do not delete it.' ,'vital' ), '<code>1200px</code>'),
        'std'         => '',
        'type'        => 'text',
        'section'     => 'blog_section',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => 'child-options',
        'condition'   => 'blog_pre_content_area:is(on)',
        'operator'    => 'and'
      ),
	  array(
        'id'          => 'blog_pre_content_paddings',
        'label'       => esc_html__( 'Paddings (optional)', 'vital' ),
		'desc'        => sprintf (esc_html_x( 'Pre-content area paddings. Example: %s', '%s stands for example value. Do not delete it.' ,'vital' ), '<code>40px</code>'),
        'std'         => '',
        'type'        => 'text',
        'section'     => 'blog_section',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => 'child-options',
        'condition'   => 'blog_pre_content_area:is(on)',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'blog_pre_content_bg',
        'label'       => esc_html__( 'Background', 'vital' ),
        'desc'        => esc_html__( 'Set custom background color or image.', 'vital' ),
        'std'         => '',
        'type'        => 'background',
        'section'     => 'blog_section',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => 'child-options',
        'condition'   => 'blog_pre_content_area:is(on)',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'blog_pre_content_html',
        'label'       => esc_html__( 'Custom HTML', 'vital' ),
        'desc'        => esc_html__( 'Insert any custom code you wish. Shortcodes allowed.', 'vital' ),
        'std'         => '',
        'type'        => 'textarea-simple',
        'section'     => 'blog_section',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => 'child-options child-last',
        'condition'   => 'blog_pre_content_area:is(on)',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'exclude_from_blog',
        'label'       => esc_html__( 'Exclude category from blog', 'vital' ),
        'desc'        => esc_html__( 'This option will exclude selected category posts from blog and search pages.', 'vital' ),
        'std'         => '',
        'type'        => 'category-checkbox',
        'section'     => 'blog_section',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'blog_offset',
        'label'       => esc_html__( 'Offset', 'vital' ),
		'desc'        => sprintf (esc_html_x( 'Number of post to displace or pass over. Example (to pass two posts enter): %s', '%s stands for example value. Do not delete it.' ,'vital' ), '<code>2</code>'),
        'std'         => '',
        'type'        => 'text',
        'section'     => 'blog_section',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
	  array(
        'id'          => 'content_type',
        'label'       => esc_html__( 'Content type', 'vital' ),
        'desc'        => esc_html__( 'Choose what to display on blog index pages. Note that only \'Full Content\' respects WordPress \'read more\' tag.', 'vital' ),
        'std'         => 'full_content',
        'type'        => 'select',
        'section'     => 'blog_section',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and',
        'choices'     => array( 
          array(
            'value'       => 'none',
            'label'       => esc_html__( 'None', 'vital' ),
            'src'         => ''
          ),
          array(
            'value'       => 'excerpt',
            'label'       => esc_html__( 'Excerpt', 'vital' ),
            'src'         => ''
          ),
          array(
            'value'       => 'full_content',
            'label'       => esc_html__( 'Full content', 'vital' ),
            'src'         => ''
          )
        )
      ),
	  array(
        'id'          => 'default_post_image',
        'label'       => esc_html__( 'Default post image', 'vital' ),
        'desc'        => esc_html__( 'This is the default image applied to all posts that do not have featured image set.', 'vital' ),
        'std'         => '',
        'type'        => 'upload',
        'section'     => 'blog_section',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => 'ot-upload-attachment-id',
        'condition'   => '',
        'operator'    => 'and'
      ),
	  array(
        'id'          => 'blog_social_share',
        'label'       => esc_html__( 'Blog social sharing', 'vital' ),
        'desc'        => esc_html__( 'Enable social sharing in blog view. More details in documentation.', 'vital' ),
        'std'         => 'off',
        'type'        => 'on-off',
        'section'     => 'blog_section',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
	  array(
        'id'          => 'blog_social_share_custom_code',
        'label'       => esc_html__( 'Custom social sharing shortcode', 'vital' ),
		'desc'        => esc_html__( 'Add your custom social sharing shortcode.', 'vital' ),
        'std'         => '',
        'type'        => 'text',
        'section'     => 'blog_section',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
		'condition'   => 'blog_social_share:is(on)',
        'operator'    => 'and'
      ),
	  array(
        'id'          => 'post_image_blog',
        'label'       => esc_html__( 'Post image', 'vital' ),
        'desc'        => esc_html__( 'Do you want to display post featured image? Works with default post style.', 'vital' ),
        'std'         => 'on',
        'type'        => 'on-off',
        'section'     => 'blog_section',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'post_review_rating',
        'label'       => esc_html__( 'Post review rating (stars)', 'vital' ),
        'desc'        => esc_html__( 'Do you want to display star rating in post meta fields?', 'vital' ),
        'std'         => 'on',
        'type'        => 'on-off',
        'section'     => 'blog_section',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'post_category_blog',
        'label'       => esc_html__( 'Post category in blog meta', 'vital' ),
        'desc'        => esc_html__( 'Do you want to display category in post meta fields?', 'vital' ),
        'std'         => 'on',
        'type'        => 'on-off',
        'section'     => 'blog_section',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'post_author_blog',
        'label'       => esc_html__( 'Post author in blog meta', 'vital' ),
        'desc'        => esc_html__( 'Do you want to display author in post meta fields?', 'vital' ),
        'std'         => 'on',
        'type'        => 'on-off',
        'section'     => 'blog_section',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'post_date_blog',
        'label'       => esc_html__( 'Post date in blog meta', 'vital' ),
        'desc'        => esc_html__( 'Do you want to display date in post meta fields?', 'vital' ),
        'std'         => 'on',
        'type'        => 'on-off',
        'section'     => 'blog_section',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'post_comments_blog',
        'label'       => esc_html__( 'Post comments in blog meta', 'vital' ),
        'desc'        => esc_html__( 'Do you want to display comment count in post meta fields?', 'vital' ),
        'std'         => 'on',
        'type'        => 'on-off',
        'section'     => 'blog_section',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'category_styles',
        'label'       => esc_html__( 'Category style', 'vital' ),
        'desc'        => esc_html__( 'Style any category different from default.', 'vital' ),
        'std'         => '',
        'type'        => 'list-item',
        'section'     => 'category_style_tab',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => 'category-styles',
        'condition'   => '',
        'operator'    => 'and',
        'settings'    => array( 
          array(
            'id'          => 'cs_select',
            'label'       => esc_html__( 'Select category', 'vital' ),
            'desc'        => esc_html__( 'Choose category to style.', 'vital' ),
            'std'         => '',
            'type'        => 'category-select',
            'rows'        => '',
            'post_type'   => '',
            'taxonomy'    => '',
            'min_max_step'=> '',
            'class'       => '',
            'condition'   => '',
            'operator'    => 'and'
          ),
          array(
            'id'          => 'category_title',
            'label'       => esc_html__( 'Category title', 'vital' ),
            'desc'        => esc_html__( 'Choose whether to display or hide category page title.', 'vital' ),
            'std'         => 'on',
            'type'        => 'on-off',
            'rows'        => '',
            'post_type'   => '',
            'taxonomy'    => '',
            'min_max_step'=> '',
            'class'       => '',
            'condition'   => '',
            'operator'    => 'and'
          ),
          array(
            'id'          => 'cat_post_style',
            'label'       => esc_html__( 'Post style', 'vital' ),
            'desc'        => esc_html__( 'Choose custom post style.', 'vital' ),
            'std'         => '',
            'type'        => 'select',
            'rows'        => '',
            'post_type'   => '',
            'taxonomy'    => '',
            'min_max_step'=> '',
            'class'       => '',
            'condition'   => '',
            'operator'    => 'and',
            'choices'     => array( 
              array(
                'value'       => 'default',
                'label'       => esc_html__( 'Inherit from blog settings', 'vital' ),
                'src'         => ''
              ),
			  array(
                'value'       => '1',
                'label'       => esc_html__( 'Default', 'vital' ),
                'src'         => ''
              ),
              array(
                'value'       => '2',
                'label'       => esc_html__( 'Image overlay', 'vital' ),
                'src'         => ''
              )  
            )
          ),
          array(
            'id'          => 'cat_post_layout',
            'label'       => esc_html__( 'Post layout', 'vital' ),
			'desc'        => sprintf (esc_html_x( '1. One column %1$s 2. Two column', '%1$s stands for line break' ,'vital' ), '<br/>'),
            'std'         => 'layout-one-column',
            'type'        => 'radio-image',
            'rows'        => '',
            'post_type'   => '',
            'taxonomy'    => '',
            'min_max_step'=> '',
            'class'       => '',
            'condition'   => '',
            'operator'    => 'or'
          ),
          array(
            'id'          => 'cat_layout',
            'label'       => esc_html__( 'Category page layout', 'vital' ),
			'desc'        => sprintf (esc_html_x( '1. Full width content %1$s 2. Content / Right sidebar %1$s 3. Content / Left sidebar', '%1$s stands for line break' ,'vital' ), '<br/>'),
            'std'         => 'right-sidebar',
            'type'        => 'radio-image',
            'rows'        => '',
            'post_type'   => '',
            'taxonomy'    => '',
            'min_max_step'=> '',
            'class'       => '',
            'condition'   => '',
            'operator'    => 'and'
          ),
		  array(
			'id'          => 'cat_content_type',
			'label'       => esc_html__( 'Content type', 'vital' ),
			'desc'        => esc_html__( 'Choose what to display on blog index pages. Note that only \'Full Content\' respects WordPress \'read more\' tag.', 'vital' ),
			'std'         => 'full_content',
			'type'        => 'select',
			'rows'        => '',
			'post_type'   => '',
			'taxonomy'    => '',
			'min_max_step'=> '',
			'class'       => '',
			'condition'   => '',
			'operator'    => 'and',
			'choices'     => array( 
			  array(
				'value'       => 'default',
				'label'       => esc_html__( 'Default (Blog settings)', 'vital' ),
				'src'         => ''
			  ),			  
			  array(
				'value'       => 'none',
				'label'       => esc_html__( 'None', 'vital' ),
				'src'         => ''
			  ),
			  array(
				'value'       => 'excerpt',
				'label'       => esc_html__( 'Excerpt', 'vital' ),
				'src'         => ''
			  ),
			  array(
				'value'       => 'full_content',
				'label'       => esc_html__( 'Full content', 'vital' ),
				'src'         => ''
			  )
			)
		  ),		  
          array(
            'id'          => 'cat_offset',
            'label'       => esc_html__( 'Offset', 'vital' ),
			'desc'        => sprintf (esc_html_x( 'Number of post to displace or pass over. Example (to pass two posts enter): %s', '%s stands for example value. Do not delete it.' ,'vital' ), '<code>2</code>'),
            'std'         => '',
            'type'        => 'text',
            'rows'        => '',
            'post_type'   => '',
            'taxonomy'    => '',
            'min_max_step'=> '',
            'class'       => '',
            'condition'   => '',
            'operator'    => 'and'
          ),
		  array(
			'id'          => 'cat_social_share',
			'label'       => esc_html__( 'Social sharing from blog options', 'vital' ),
			'desc'        => esc_html__( 'Enable social sharing settings set in blog options. ', 'vital' ),
			'std'         => 'on',
			'type'        => 'on-off',
			'rows'        => '',
			'post_type'   => '',
			'taxonomy'    => '',
			'min_max_step'=> '',
			'class'       => '',
			'condition'   => '',
			'operator'    => 'and'
		  ),
          array(
            'id'          => 'cat_pre_content_area',
            'label'       => esc_html__( 'Pre-content area', 'vital' ),
            'desc'        => esc_html__( 'Activates additional area before main content.', 'vital' ),
            'std'         => 'off',
            'type'        => 'on-off',
            'rows'        => '',
            'post_type'   => '',
            'taxonomy'    => '',
            'min_max_step'=> '',
            'class'       => '',
            'condition'   => '',
            'operator'    => 'and'
          ),
          array(
            'id'          => 'cat_pre_content_height',
            'label'       => esc_html__( 'Height (optional)', 'vital' ),
			'desc'        => sprintf (esc_html_x( 'Pre-content area height. Example: %s', '%s stands for example value. Do not delete it.' ,'vital' ), '<code>250px</code>'),
            'std'         => '',
            'type'        => 'text',
            'rows'        => '',
            'post_type'   => '',
            'taxonomy'    => '',
            'min_max_step'=> '',
            'class'       => 'child-options child-first',
            'condition'   => 'cat_pre_content_area:is(on)',
            'operator'    => 'and'
          ),
		  array(
            'id'          => 'cat_pre_content_responsive_height',
            'label'       => esc_html__( 'Responsive height (optional)', 'vital' ),
            'desc'        => esc_html__( 'Enables auto height in responsive mode.', 'vital' ),
            'std'         => 'off',
            'type'        => 'on-off',
            'rows'        => '',
            'post_type'   => '',
            'taxonomy'    => '',
            'min_max_step'=> '',
            'class'       => 'child-options',
            'condition'   => 'cat_pre_content_area:is(on)',
            'operator'    => 'and'
          ),
          array(
            'id'          => 'cat_pre_content_width',
            'label'       => esc_html__( 'Max width (optional)', 'vital' ),
			'desc'        => sprintf (esc_html_x( 'Pre-content area max width. Example: %s', '%s stands for example value. Do not delete it.' ,'vital' ), '<code>1200px</code>'),
            'std'         => '',
            'type'        => 'text',
            'rows'        => '',
            'post_type'   => '',
            'taxonomy'    => '',
            'min_max_step'=> '',
            'class'       => 'child-options',
            'condition'   => 'cat_pre_content_area:is(on)',
            'operator'    => 'and'
          ),
		  array(
			'id'          => 'cat_pre_content_paddings',
			'label'       => esc_html__( 'Paddings (optional)', 'vital' ),
			'desc'        => sprintf (esc_html_x( 'Pre-content area paddings. Example: %s', '%s stands for example value. Do not delete it.' ,'vital' ), '<code>40px</code>'),
			'std'         => '',
			'type'        => 'text',
			'rows'        => '',
			'post_type'   => '',
			'taxonomy'    => '',
			'min_max_step'=> '',
			'class'       => 'child-options',
			'condition'   => 'cat_pre_content_area:is(on)',
			'operator'    => 'and'
		  ),		  
          array(
            'id'          => 'cat_pre_content_bg',
            'label'       => esc_html__( 'Background', 'vital' ),
            'desc'        => esc_html__( 'Set custom background color or image.', 'vital' ),
            'std'         => '',
            'type'        => 'background',
            'rows'        => '',
            'post_type'   => '',
            'taxonomy'    => '',
            'min_max_step'=> '',
            'class'       => 'child-options',
            'condition'   => 'cat_pre_content_area:is(on)',
            'operator'    => 'and'
          ),
          array(
            'id'          => 'cat_pre_content_html',
            'label'       => esc_html__( 'Custom HTML', 'vital' ),
            'desc'        => esc_html__( 'Insert any custom code you wish. Shortcodes are allowed.', 'vital' ),
            'std'         => '',
            'type'        => 'textarea-simple',
            'rows'        => '10',
            'post_type'   => '',
            'taxonomy'    => '',
            'min_max_step'=> '',
            'class'       => 'child-options child-last',
            'condition'   => 'cat_pre_content_area:is(on)',
            'operator'    => 'and'
          )
        )
      ),
      array(
        'id'          => 'cart_widget',
        'label'       => esc_html__( 'Display cart content on hover', 'vital' ),
        'desc'        => esc_html__( 'Display cart content on icon hover (ON) or just lead to cart page on click (OFF)?', 'vital' ),
        'std'         => 'on',
        'type'        => 'on-off',
        'section'     => 'woocommerce',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => 'cart_button:is(on)',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'catalog_layout',
        'label'       => esc_html__( 'Product archive page (shop) layout', 'vital' ),
		'desc'        => sprintf (esc_html_x( '1. Full width content %1$s 2. Content / Right sidebar %1$s 3. Content / Left sidebar', '%1$s stands for line break' ,'vital' ), '<br/>'),
        'std'         => 'full-width',
        'type'        => 'radio-image',
        'section'     => 'woocommerce',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
	  array(
        'id'          => 'product_layout',
        'label'       => esc_html__( 'Single product page layout', 'vital' ),
		'desc'        => sprintf (esc_html_x( '1. Full width content %1$s 2. Content / Right sidebar %1$s 3. Content / Left sidebar', '%1$s stands for line break' ,'vital' ), '<br/>'),
        'std'         => 'right-sidebar',
        'type'        => 'radio-image',
        'section'     => 'woocommerce',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'woo_title',
        'label'       => esc_html__( 'WooCommerce product page title', 'vital' ),
        'desc'        => esc_html__( 'Enable or disable title for main WooCommerce shop page.', 'vital' ),
        'std'         => 'on',
        'type'        => 'on-off',
        'section'     => 'woocommerce',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
     array(
        'id'          => 'woo_pre_content_area',
        'label'       => esc_html__( 'Pre-content area', 'vital' ),
        'desc'        => esc_html__( 'Activates additional area before main content.', 'vital' ),
        'std'         => 'off',
        'type'        => 'on-off',
        'section'     => 'woocommerce',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'woo_pre_content_height',
        'label'       => esc_html__( 'Height (optional)', 'vital' ),
		'desc'        => sprintf (esc_html_x( 'Pre-content area height. Example: %s', '%s stands for example value. Do not delete it.' ,'vital' ), '<code>250px</code>'),
        'std'         => '',
        'type'        => 'text',
        'section'     => 'woocommerce',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => 'child-options child-first',
        'condition'   => 'woo_pre_content_area:is(on)',
        'operator'    => 'and'
      ),
	  array(
        'id'          => 'woo_pre_content_responsive_height',
        'label'       => esc_html__( 'Responsive height (optional)', 'vital' ),
        'desc'        => esc_html__( 'Enables auto height in responsive mode.', 'vital' ),
        'std'         => 'off',
        'type'        => 'on-off',
        'section'     => 'woocommerce',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => 'child-options',
        'condition'   => 'woo_pre_content_area:is(on)',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'woo_pre_content_width',
        'label'       => esc_html__( 'Max width (optional)', 'vital' ),
		'desc'        => sprintf (esc_html_x( 'Pre-content area max width. Example: %s', '%s stands for example value. Do not delete it.' ,'vital' ), '<code>1200px</code>'),
        'std'         => '',
        'type'        => 'text',
        'section'     => 'woocommerce',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => 'child-options',
        'condition'   => 'woo_pre_content_area:is(on)',
        'operator'    => 'and'
      ),
	  array(
        'id'          => 'woo_pre_content_paddings',
        'label'       => esc_html__( 'Paddings (optional)', 'vital' ),
		'desc'        => sprintf (esc_html_x( 'Pre-content area paddings. Example: %s', '%s stands for example value. Do not delete it.' ,'vital' ), '<code>40px</code>'),
        'std'         => '',
        'type'        => 'text',
        'section'     => 'woocommerce',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => 'child-options',
        'condition'   => 'woo_pre_content_area:is(on)',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'woo_pre_content_bg',
        'label'       => esc_html__( 'Background', 'vital' ),
        'desc'        => esc_html__( 'Set custom background color or image.', 'vital' ),
        'std'         => '',
        'type'        => 'background',
        'section'     => 'woocommerce',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => 'child-options',
        'condition'   => 'woo_pre_content_area:is(on)',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'woo_pre_content_html',
        'label'       => esc_html__( 'Custom HTML', 'vital' ),
        'desc'        => esc_html__( 'Insert any custom code you wish. Shortcodes allowed.', 'vital' ),
        'std'         => '',
        'type'        => 'textarea-simple',
        'section'     => 'woocommerce',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => 'child-options child-last',
        'condition'   => 'woo_pre_content_area:is(on)',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'woo_columns',
        'label'       => esc_html__( 'Product column count', 'vital' ),
        'desc'        => esc_html__( 'Choose column count for main product catalog page.', 'vital' ),
        'std'         => '3',
        'type'        => 'select',
        'section'     => 'woocommerce',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and',
        'choices'     => array( 
          array(
            'value'       => '3',
            'label'       => esc_html__( '3 columns', 'vital' ),
            'src'         => ''
          ),
          array(
            'value'       => '4',
            'label'       => esc_html__( '4 columns', 'vital' ),
            'src'         => ''
          )
        )
      ),
      array(
        'id'          => 'woo_product_count',
        'label'       => esc_html__( 'Products per page', 'vital' ),
        'desc'        => esc_html__( 'Choose how many products to display on product catalog page.', 'vital' ),
        'std'         => '12',
        'type'        => 'text',
        'section'     => 'woocommerce',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'custom_css',
        'label'       => esc_html__( 'Custom CSS', 'vital' ),
		'desc'        => sprintf (esc_html_x( 'Add any of your custom CSS here: %1$s %2$s Have fun!', '%1$s stands for line break, %2$s stand for example code' ,'vital' ), '<br/>', '<pre><code>.page-id-10 #site-header {background: none;}</code></pre>'),
        'std'         => '',
        'type'        => 'textarea-simple',
        'section'     => 'custom_css',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      )
    )
  );
  
  /* allow settings to be filtered before saving */
  $custom_settings = apply_filters( ot_settings_id() . '_args', $custom_settings );
  
  /* settings are not the same update the DB */
  if ( $saved_settings !== $custom_settings ) {
    update_option( ot_settings_id(), $custom_settings ); 
  }
  
  /* Lets OptionTree know the UI Builder is being overridden */
  global $ot_has_custom_theme_options;
  $ot_has_custom_theme_options = true;
  
}